import wx
import sys
import time

from gooey import Gooey, GooeyParser, constants

bg_color = "#000000"
font_color = "#7CFC00"


@Gooey(program_name="This is a cool name")
def gooey_app():
    parser = GooeyParser()

    parser.add_argument('a',
                        metavar='N',
                        type=str,
                        nargs='+',
                        widget='FileChooser')

    parser.add_argument('paths',
                        metavar='N',
                        type=str,
                        nargs='+',
                        widget='MultiFileChooser')
    args = parser.parse_args()

    # Do something for a long time
    print(args)
    print(len(args.paths))
    for i in args.paths:
        print(i)

if __name__ == '__main__':
    sys.exit(gooey_app())



parser.add_argument('paths',
metavar='N',
type=str,
nargs='+',
widget='MultiFileChooser')


from gooey import Gooey, GooeyParser

@Gooey()
def main():
    parser = GooeyParser(description='Process some integers.')

    parser.add_argument(
        "--arg1",
        action="store",
        default="c1",
        choices=("c1", "c2", "c3"),
    )

    args = parser.parse_args()


if __name__ == '__main__':
    main()


'''
Created on Dec 21, 2013
 __          __  _
 \ \        / / | |
  \ \  /\  / /__| | ___ ___  _ __ ___   ___
   \ \/  \/ / _ \ |/ __/ _ \| '_ ` _ \ / _ \
    \  /\  /  __/ | (_| (_) | | | | | |  __/
  ___\/__\/ \___|_|\___\___/|_| |_| |_|\___|
 |__   __|
    | | ___
    | |/ _ \
    | | (_) |
   _|_|\___/                    _ _
  / ____|                      | | |
 | |  __  ___   ___   ___ _   _| | |
 | | |_ |/ _ \ / _ \ / _ \ | | | | |
 | |__| | (_) | (_) |  __/ |_| |_|_|
  \_____|\___/ \___/ \___|\__, (_|_)
                           __/ |
                          |___/

@author: Chris
'''

from argparse import ArgumentParser
from collections import OrderedDict

from gooey.python_bindings.gooey_decorator import Gooey
from gooey.python_bindings.gooey_parser import GooeyParser






@Gooey(
    sidebar_title="Your Custom Title",
    show_sidebar=False,
    tabbed_groups=False,
    dump_build_config=False,
    required_cols=3,
    optional_cols=1,
    requires_shell=True
)
def main():

    import sys
    print("sys.argv sys.argv sys.argv sys.argv sys.argv sys.argv")
    print(sys.argv)
    print('\n\n')
    print(repr(sys.argv))
    desc = "Example application to show Gooey's various widgets"
    file_help_msg = "Name of the file you want to process"
    my_cool_parser = GooeyParser(description=desc, add_help=False)

    my_cool_parser.add_argument('thing', default='.',
                                widget='MultiFileChooser',
                                help="asdfsadfasdfa sdfadf ad")
    # my_cool_parser.add_argument(
    #     "region_name_list",
    #     help="Which regions do you want to run it for?",
    #     choices=['one' ,'two', 'three'],
    #     nargs="+",
    #     widget="Listbox",
    #     # widget='Counter'
    # )

    my_cool_parser.add_argument("FileChooser",
                    help=file_help_msg,
                    )

    my_cool_parser.add_argument("Outfile",
                                widget='FileChooser',
                                metavar='Output Target',
                                help='Target output file',
                                gooey_options={
                                    'wildcard': 'Some Files (*.png)|*.png',
                                    'label_color': 1234

                                }
                                # gooey_options={
                                #     'validator': {
                                #         'test': 'user_input == "foo"',
                                #         'message': 'Must be a valid filename'
                                #     }
                                # }
                                )
    my_cool_parser.add_argument('--listboxie',
                    metavar='Multiple selection',
                    nargs='+',
                    default=['Option three', 'Option four'],
                    choices=['Option one', 'Option two', 'Option three',
                             'Option four'],
                    help='Choose an action!',
                    widget='Listbox',
                    gooey_options={
                        'height': 500,
                        'validate': '',
                        'heading_color': '',
                        'text_color': '',
                        'hide_heading': True,
                        'hide_text': True,
                    }
                    )
    #
    search_options = my_cool_parser.add_argument_group(
        'Search Options', 'Customize the search options',
        gooey_options={
            'show_border': True,
            'columns': 2
        }
    )

    x = search_options.add_argument('--query', help='base search string'
                                    # , gooey_options={'full_width': True}
                                    )
    search_options.add_argument('--other', help='Another option in the search group'
                                # , gooey_options={'full_width': True}
                                )
    search_options.add_argument('--one-more', help='And another one'
                                # , gooey_options={'full_width': True}
                                )

    search_flags = search_options.add_argument_group('Flags',
                                                     gooey_options={'show_border': True}
                                                     )
    search_flags.add_argument('--buy-it-now', help="Will immediately purchase if possible", action='store_true')
    search_flags.add_argument('--auction', help="Place bids up to PRICE_MAX", action='store_true')

    price_range = search_options.add_argument_group('Price_Range',
                                                    gooey_options={'show_border': True}
                                                    )

    price_range.add_argument('--price-min', help='min price')
    price_range.add_argument('--price-max', help='max price')

    foobar = search_options.add_mutually_exclusive_group(
        gooey_options={'title': 'Numeric Mutexes',
                       'show_border': False,
                       'label_color': '#00ff00'}
    )
    foobar.add_argument('--one', help='oneie')
    foobar.add_argument('--two', help='twoie')
    foobar.add_argument('--three', help='twoie', action='store_true')

    my_cool_parser.add_argument("DirChooser", help=file_help_msg, widget="DirChooser")
    my_cool_parser.add_argument("FileSaver", help=file_help_msg, widget="FileSaver")
    my_cool_parser.add_argument("MultiFileSaver", help=file_help_msg, widget="MultiFileChooser")
    # my_cool_parser.add_argument("MultiDirSaver", help="Directories to open", widget='MultiDirChooser')

    my_cool_parser.add_argument('-j', '--jaws', help='ooop',
                                widget="MultiFileChooser",
                                default="Yo yo!",
                                gooey_options={
                                    'validator': {
                                        'test': 'len(user_input) > 5',
                                        'message': 'Must be over 5 chars!'
                                    }
                                }
                                )
    my_cool_parser.add_argument('-d', '--duration', default=2, type=int,
                                help='Duration (in seconds) of the program output')
    my_cool_parser.add_argument('-u', '--textarea', default="I'm on \na new line",
                                type=str, help='A multiline textarea',
                                widget='Textarea',
                                gooey_options={
                                    'height': 100
                                }
                                )
    my_cool_parser.add_argument('-s', '--cron-schedule', type=int,
                                help='datetime when the cron should begin',
                                widget='DateChooser')
    my_cool_parser.add_argument("-c", "--showtime", action="store_true",
                                help="display the countdown timer")
    my_cool_parser.add_argument("-y", "--yolo", action="store_true",
                                widget='BlockCheckbox',
                                help="display the countdown timer")
    my_cool_parser.add_argument("-p", "--pause", action="store_true",
                                help="Pause execution")
    my_cool_parser.add_argument('-v', '--verbose', action='count')
    my_cool_parser.add_argument("-o", "--overwrite", action="store_true",
                                default=True,
                                help="Overwrite output file (if present)")
    my_cool_parser.add_argument('-r', '--recursive', choices=['yes', 'no'],
                                help='Recurse into subfolders')
    # my_cool_parser.add_argument('-y', '--listboxie',
    #                             nargs='+',
    #                             choices=['hello', 'ay', 'yeah', 'boiiiii', 'wssup', 'longest', 'yeahhhboiii', 'ever'],
    #                             help='Recurse into subfolders',
    #                             widget='Listbox')
    my_cool_parser.add_argument("-w", "--writelog", default="writelogs",
                                help="Dump output to local file")
    my_cool_parser.add_argument("-e", "--error", action="store_true",
                                help="Stop process on error (default: No)")
    verbosity = my_cool_parser.add_mutually_exclusive_group(required=False)
    verbosity.add_argument('-t', '--verbozze', dest='verbose', action='store_true',
                           help="Show more details")
    verbosity.add_argument('-q', '--quiet', dest='quiet',
                           help="Only output on error",
                           # widget='DirChooser'
                           )

    # my_cool_parser.add_argument('--sum', dest='accumulate', action='store_const',
    #                     const=sum, default=max,
    #                     help='sum the integers (default: find the max)')

    import pprint



    # stuff = [extract(x) for x in my_cool_parser._action_groups]
    # mutex_groups = [group for group in my_cool_parser._mutually_exclusive_groups]
    #
    # pprint.pprint(reapply_mutex_groups(mutex_groups, stuff))
    # my_cool_parser.print_help()
    args = my_cool_parser.parse_args()
    print(args)
    # time.sleep(5)
    print("Hiya!")
    for i in range(20):
        import time
        print('Howdy', i)
        time.sleep(.3)
    # print(args.listboxie)


def here_is_smore():
    pass


if __name__ == '__main__':
    main()



import wx

from gooey.gui import formatters
from gooey.gui.components.widgets.bases import TextContainer


class Listbox(TextContainer):

    def getWidget(self, parent, *args, **options):
        height = self._options.get('height', 60)
        return wx.ListBox(
            parent=parent,
            choices=self._meta['choices'],
            size=(-1, height),
            style=wx.LB_MULTIPLE
        )

    def setOptions(self, options):
        self.widget.Clear()
        for option in options:
            self.widget.Append(option)

    def setValue(self, values):
        for string in values:
            self.widget.SetStringSelection(string)

    def getWidgetValue(self):
        return [self.widget.GetString(index)
                for index in self.widget.GetSelections()]

    def formatOutput(self, metadata, value):
        return formatters.listbox(metadata, value)



from gooey import Gooey, GooeyParser


@Gooey(program_name="Widget Demo")
def main():
    my_cool_parser = GooeyParser()

    my_cool_parser.add_argument('--No', choices=[True, False], default=True)
    my_cool_parser.add_argument('--Yes', choices=[True, False], default=False)

    args = my_cool_parser.parse_args()


if __name__ == '__main__':
    main()


from gooey import Gooey, GooeyParser


@Gooey(program_name="Widget Demo")
def main():
    parent = GooeyParser()
    group = parent.add_mutually_exclusive_group('mutex-group')
    group.add_argument("--a_file", widget="FileChooser")
    group.add_argument("--b_file", widget="DirChooser")

    parser = GooeyParser(parents=[parent], add_help=False)
    parser.add_argument('--c_file', widget='FileChooser')


    args = parser.parse_args()


if __name__ == '__main__':
    main()






"""
Example program to demonstrate Gooey's presentation of subparsers
"""

from gooey import Gooey, GooeyParser

@Gooey(
    optional_cols=2,
    program_name="Subparser Demo",
    dump_build_config=True,
    show_success_modal=False)
def main():
    dest_vars = [
        'textfield',
        'textarea',
        'password',
        'commandfield',
        'dropdown',
        'listboxie',
        'counter',
        'overwrite',
        'mutextwo',
        'filechooser',
        'filesaver',
        'dirchooser',
        'datechooser'
    ]
    parser = get_parser()
    args = parser.parse_args()
    import time
    time.sleep(.6)
    for i in dest_vars:
        assert getattr(args, i) is not None
    print("Success")


def get_parser():
    parser = GooeyParser()
    subs = parser.add_subparsers(help='commands', dest='command')

    parser_one = subs.add_parser('parser1', prog="Parser 1")
    parser_one.add_argument('--textfield', default=2, widget="TextField")
    parser_one.add_argument('--textarea', default="oneline twoline",
                            widget='Textarea')
    parser_one.add_argument('--password', default="hunter42",
                            widget='PasswordField')
    parser_one.add_argument('--commandfield', default="cmdr",
                            widget='CommandField')
    parser_one.add_argument('--dropdown',
                            choices=["one", "two"], default="two",
                            widget='Dropdown')
    parser_one.add_argument('--listboxie',
                            nargs='+',
                            default=['Option three', 'Option four'],
                            choices=['Option one', 'Option two', 'Option three',
                                     'Option four'],
                            widget='Listbox',
                            gooey_options={
                                'height': 300,
                                'validate': '',
                                'heading_color': '',
                                'text_color': '',
                                'hide_heading': True,
                                'hide_text': True,
                            }
                            )
    parser_one.add_argument('-c', '--counter', default=3, action='count',
                            widget='Counter')
    #
    parser_one.add_argument("-o", "--overwrite", action="store_true",
                            default=True,
                            widget='CheckBox')

    ### Mutex Group ###
    verbosity = parser_one.add_mutually_exclusive_group(
        required=True,
        gooey_options={
            'initial_selection': 1
        }
    )
    verbosity.add_argument(
        '--mutexone',
        default=True,
        action='store_true',
        help="Show more details")

    verbosity.add_argument(
        '--mutextwo',
        default='mut-2',
        widget='TextField')

    parser_one.add_argument("--filechooser", default="fc-value", widget='FileChooser')
    parser_one.add_argument("--filesaver", default="fs-value", widget='FileSaver')
    parser_one.add_argument("--dirchooser", default="dc-value", widget='DirChooser')
    parser_one.add_argument("--datechooser", default="2015-01-01", widget='DateChooser')

    parser_two = subs.add_parser('parser2', prog="parser 2")
    parser_two.add_argument('--textfield', default=2, widget="TextField")
    parser_two.add_argument('--textarea', default="oneline twoline", widget='Textarea')
    parser_two.add_argument('--password', default="hunter42", widget='PasswordField')
    parser_two.add_argument('--commandfield', default="cmdr", widget='CommandField')
    parser_two.add_argument('--dropdown', choices=["one", "two"], default="two", widget='Dropdown')
    parser_two.add_argument('--listboxie',
                            nargs='+',
                            default=['Option three', 'Option four'],
                            choices=['Option one', 'Option two', 'Option three',
                                     'Option four'],
                            widget='Listbox',
                            gooey_options={
                                'height': 300,
                                'validate': '',
                                'heading_color': '',
                                'text_color': '',
                                'hide_heading': True,
                                'hide_text': True,
                            }
                            )
    parser_two.add_argument('-c', '--counter', default=3, action='count', widget='Counter')
    parser_two.add_argument("-o", "--overwrite", action="store_true", default=True, widget='CheckBox')

    ### Mutex Group ###
    verbosity = parser_two.add_mutually_exclusive_group(
        required=True,
        gooey_options={
            'initial_selection': 1
        }
    )
    verbosity.add_argument(
        '--mutexone',
        default=True,
        action='store_true',
        help="Show more details")

    verbosity.add_argument(
        '--mutextwo',
        default='mut-2',
        widget='TextField')

    parser_two.add_argument("--filechooser", default="fc-value", widget='FileChooser')
    parser_two.add_argument("--filesaver", default="fs-value", widget='FileSaver')
    parser_two.add_argument("--dirchooser", default="dc-value", widget='DirChooser')
    parser_two.add_argument("--datechooser", default="2015-01-01", widget='DateChooser')

    return parser

if __name__ == '__main__':
    main()



from gooey import Gooey, GooeyParser, options
from argparse import ArgumentParser

def some_function(id_, len_):
    print(id_)
    print(len_)
    return

@Gooey(program_name = "Machine Learning Pipeline - Spatial Proximity Check",
       required_cols = 2,
       tabbed_groups=True)
def main_spatial_proximity_gui():
    parser = GooeyParser(description = "Machine Learning Pipeline - Base Data Input")
    parser.add_argument(
        '--pipeline_dataset',
        metavar = 'Pipeline Dataset (csv)',
        choices=['a', 'b', 'c'],
        widget = 'FilterableDropdown',
        gooey_options=options.TextField(
            initial_value='Helllloooo'
        )
    )
    parser.add_argument(
        '--version',
        action='version',
        version='%(prog)s 2.0'
    )
    args = parser.parse_args()
    print(args)




main_spatial_proximity_gui()



"""
This weirdness exists to work around a very specific problem
with testing WX: you can only ever have one App() instance per
process. I've spent hours and hours trying to work around this and
figure out how to gracefully destroy and recreate them, but... no dice.

This is echo'd in the docs: https://wxpython.org/Phoenix/docs/html/wx.App.html

Destroying/recreating causes instability in the tests. We can work around that
by reusing the same App instance across tests and only destroying the top level
frame (which is fine). However, this causes a new problem: the last test which
runs will now always fail, cause we're not Destroying the App instance.

Ideal world: UnitTest would expose a global "done" hook regardless of test
discovery type. That doesn't exist, so the best we can do is use the Module cleanup
methods. These aren't perfect, but destroying / recreating at the module boundary
gives slightly more reliable tests. These are picked up by the test runner
by their existence in the module's globals(). There's no other way to hook
things together. We need it in every test, and thus... that's the background
for why this weirdness is going on.

It's a hack around a hack around a problem in Wx.

Usage:

In any tests which use WX, you must import this module's definitions
into the test's global scope

```
from gooey.tests import *
```
"""
import wx

app = None

def setUpModule():
    global app
    app = wx.App()

def tearDownModule():
    global app
    app.Destroy()


import wx
import sys
import time

from gooey import Gooey, GooeyParser, constants
from gooey.gui.components.widgets.core import TextInput

bg_color = "#000000"
font_color = "#7CFC00"


@Gooey(program_name="This is a cool name")
def gooey_app():
    parser = GooeyParser()

    parser.add_argument('-f', '--foo',
                        help="Hello world!",
                        dest='foobar',
                        metavar='Hello World!',
                        action='count',
                        gooey_options={
        'label_color': '#ffffff'
    })

    parser.add_argument('-f', '--foo',
                        help="Hello world!",
                        dest='foobar',
                        metavar='Hello World!',
                        action='count',
                        widget=TextInput(
                            label_color='#fff',
                            placeholder='One Two Three'
                        ))
    args = parser.parse_args()

    # Do something for a long time
    print(args)

if __name__ == '__main__':
    sys.exit(gooey_app())


import wx
from functools import reduce

from gooey.gui.components.widgets.core.text_input import MultilineTextInput
from gooey.gui.components.widgets.textfield import TextField
from gooey.gui.components.widgets.bases import TextContainer
from gooey.gui import formatters


class Textarea(TextContainer):

    def getWidget(self, parent, *args, **options):
        widgetHeight = self._options.get('height', -1)
        return wx.TextCtrl(
            parent=parent,
            size=(-1, widgetHeight),
            style=self.getModifiers()
        )

    def getModifiers(self):
        readonly = (wx.TE_READONLY
                    if self._options.get('readonly', False)
                    # using TE_MUTLI as a safe OR-able no-op value
                    else wx.TE_MULTILINE)
        return reduce(lambda acc, val: acc | val, [wx.TE_MULTILINE, readonly])

    def getWidgetValue(self):
        return self.widget.GetValue()

    def setValue(self, value):
        self.widget.Clear()
        self.widget.AppendText(str(value))
        self.widget.SetInsertionPoint(0)

    def formatOutput(self, metatdata, value):
        return formatters.general(metatdata, value)





import webbrowser

import wx

from gooey.gui.lang.i18n import _
from .widgets.basictextconsole import BasicTextConsole


class Console(wx.Panel):
    '''
    Textbox console/terminal displayed during the client program's execution.
    '''

    def __init__(self, parent, buildSpec, **kwargs):
        wx.Panel.__init__(self, parent, **kwargs)
        self.buildSpec = buildSpec

        self.text = wx.StaticText(self, label=_("status"))
        if buildSpec["richtext_controls"]:
            from .widgets.richtextconsole import RichTextConsole
            self.textbox = RichTextConsole(self)
        else:
            self.textbox = BasicTextConsole(self)

        self.defaultFont = self.textbox.GetFont()

        self.textbox.SetFont(wx.Font(
            self.buildSpec['terminal_font_size'] or self.defaultFont.GetPointSize(),
            self.getFontStyle(),
            wx.NORMAL,
            self.buildSpec['terminal_font_weight'] or wx.NORMAL,
            False,
            self.getFontFace(),
        ))
        self.textbox.SetForegroundColour(self.buildSpec['terminal_font_color'])
         
        self.layoutComponent()
        self.Layout()
        self.Bind(wx.EVT_TEXT_URL, self.evtUrl, self.textbox)

    def evtUrl(self, event):
        if event.MouseEvent.LeftUp():
            # The rich console provides the embedded URL via GetString()
            # but the basic console does not
            webbrowser.open(
                event.GetString() or
                self.textbox.GetRange(event.URLStart,event.URLEnd))
        event.Skip()


    def getFontStyle(self):
        """
        Force wx.Modern style to support legacy
        monospace_display param when present
        """
        return (wx.MODERN
                if self.buildSpec['monospace_display']
                else wx.DEFAULT)


    def getFontFace(self):
        """Choose the best font face available given the user options"""
        userFace = self.buildSpec['terminal_font_family'] or self.defaultFont.GetFaceName()
        return (''
                if self.buildSpec['monospace_display']
                else userFace)


    def logOutput(self, *args, **kwargs):
        """Event Handler for console updates coming from the client's program"""
        self.appendText(kwargs.get('msg'))


    def appendText(self, txt):
        """
        Append the text to the main TextCtrl.

        Note! Must be called from a Wx specific thread handler to avoid
        multi-threaded explosions (e.g. wx.CallAfter)
        """
        self.textbox.AppendText(txt)

    def clear(self):
        """
            Clear the the main TextCtrl.
        """
        self.textbox.Clear()


    def getText(self):
        return self.textbox.GetValue()

    def layoutComponent(self):
        self.SetBackgroundColour(self.buildSpec.get('terminal_panel_color', '#F0F0F0'))
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.AddSpacer(10)
        sizer.Add(self.text, 0, wx.LEFT, 20)
        sizer.AddSpacer(10)
        sizer.Add(self.textbox, 1, wx.LEFT | wx.RIGHT | wx.BOTTOM | wx.EXPAND, 20)
        sizer.AddSpacer(20)
        self.SetSizer(sizer)





import subprocess

from gooey import GooeyParser, Gooey
from gui.components.options import options

positions = {
    'Center': 'overlay=(W-w)/2:(H-h)/2',
    'Top Left': 'overlay=5:5',
    'Top Right': 'overlay=W-w-5:5',
    'Bottom Left': 'overlay=5:H-h-5',
    'Bottom Right': 'overlay=W-w-5:H-h-5',
}

@Gooey(program_name='Visual FFMPEG')
def version1():
    parser = GooeyParser(description='Visual FFMPEG')
    start_position = parser.add_mutually_exclusive_group(
        'foo',
        gooey_options=options.MutexGroup(
            initial_selection=0,
            full_width=True

        ))
    start_position.add_argument(
        '--ss',
        metavar='All screens',
        help='Records ALL the screens available',
        action='store_true')
    start_position.add_argument(
        '--sss',
        help='start-position as a concrete timestamp',
        gooey_options=options.TextField(
            placeholder='HH:MM:SS',
            validator=options.RegexValidator(
                test='^\d{2}:\d{2}:\d{2}$',
                message='Must be in the format HH:MM:SS'
            )
        ))
    # input_group = parser.add_argument_group('Input', gooey_options=options.ArgumentGroup(
    #     show_border=True
    # ))
    # # basic details
    parser.add_argument(
        '--input',
        help='The video you want to add a watermark to',
        # default=r'C:\Users\Chris\Desktop\Recording #1.mp4',
        widget='TextField',
        gooey_options=options.TextField(
            placeholder='Hello world!',
            wildcard='video files (*.mp4)|*.mp4',
            full_width=True,
            validator={
                'type': 'RegexValidator',
                'test': '^\d{2}:\d{2}:\d{2}$',
                'message': 'you fucked up!'
            })
    )
    # input_group.add_argument(
    #     'watermark',
    #     help='The watermark',
    #     default=r'C:\Users\Chris\Desktop\avatar.png',
    #     widget='FileChooser',
    #     gooey_options=options.FileChooser(
    #         wildcard='PNG files (*.png)|*.png|JPEG files (*.jpeg;*.jpg)|*.jpeg;*.jpg|BMP and GIF files (*.bmp;*.gif)|*.bmp;*.gif',
    #         full_width=True
    #     ))
    #
    # output_group = parser.add_argument_group('Output', gooey_options=options.ArgumentGroup(
    #     show_border=True
    # ))
    # output_group.add_argument(
    #     'output',
    #     help='Choose where to save the output video',
    #     default=r'C:\Users\Chris\Desktop\output.mp4',
    #     widget='FileSaver',
    #     gooey_options=options.FileSaver(
    #         wildcard='video files (*.mp4)|*.mp4',
    #         default_file='output.mp4',
    #         full_width=True
    #     ))
    #
    # output_group.add_argument(
    #     '--overwrite',
    #     metavar='Overwrite existing',
    #     help='Overwrite the output video if it already exists?',
    #     action='store_const',
    #     default=True,
    #     const='-y',
    #     widget='CheckBox')
    #
    # settings = parser.add_argument_group('Settings', gooey_options=options.ArgumentGroup(
    #     show_border=True
    # ))
    # settings.add_argument(
    #     '--opacity',
    #     type=float,
    #     default=75,
    #     widget='Slider',
    #     help='Choose the opacity of the watermark (0-100)', gooey_options=options.DecimalField(
    #         min=0,
    #         max=100,
    #         increment_size=1,
    #     ))
    # settings.add_argument(
    #     '--position',
    #     choices=list(positions.keys()),
    #     default='Center',
    #     help='Position of the watermark')
    args = parser.parse_args()
    print(args)

    cmd_template = 'ffmpeg -i "{input}" ' \
                   '-i "{watermark}" ' \
                   '{overwrite} ' \
                   '-filter_complex "[1]format=rgba,colorchannelmixer=aa={opacity}[logo];[0][logo]{overlay}" ' \
                   '-codec:a copy "{output}"'

    final_cmd = cmd_template.format(
        input=args.input,
        watermark=args.watermark,
        opacity=args.opacity / 100.0,
        overlay=positions[args.position],
        overwrite=args.overwrite,
        output=args.output
    )

    process = subprocess.Popen(
        final_cmd,
        bufsize=1,
        stdout=subprocess.PIPE,
        stdin=subprocess.PIPE,
        stderr=subprocess.STDOUT,
        universal_newlines=True,
        shell=True
    )
    for line in process.stdout:
        print(line)

if __name__ == '__main__':
    version1()


from gooey import Gooey, GooeyParser


@Gooey
def main():
    parser = GooeyParser()
    parser.add_argument('filename1')
    parser.add_argument(
        'secret-advanced-argument',
        default='TOO POWERFUL!!',
        gooey_options={'visible': False}
    )
    args = parser.parse_args()


if __name__ == '__main__':
    main()


'''
Created on Feb 2, 2014

@author: Chris
'''
import time
from gooey import Gooey

@Gooey
def main():
  end = time.time() + 3
  while end > time.time():
    print 'Hello!', time.time()
    time.sleep(.8)


if __name__ == '__main__':
  main()




from argparse import *
from pathlib import Path
from gooey import Gooey

@Gooey(dump_build_config=True)
def main():
    parser = ArgumentParser()
    parser.add_argument("--foo", default=SUPPRESS)
    parser.add_argument('--version', action='version', version='1.0')
    print(parser.parse_args())

main()


import re
from functools import wraps

from gooey.gui.components.filtering.prefix_filter import OperatorType


class SuperBool(object):
    """
    A boolean which keeps with it the rationale
    for when it is false.
    """
    def __init__(self, value, rationale):
        self.value = value
        self.rationale = rationale

    def __bool__(self):
        return self.value

    __nonzero__ = __bool__

    def __str__(self):
        return str(self.value)


def lift(f):
    """
    Lifts a basic predicate to the SuperBool type
    stealing the docstring as the rationale message.

    This is largely just goofing around and experimenting
    since it's a private internal API.
    """
    @wraps(f)
    def inner(value):
        result = f(value)
        return SuperBool(result, f.__doc__) if not isinstance(result, SuperBool) else result
    return inner


@lift
def is_tuple_or_list(value):
    """Must be either a list or tuple"""
    return isinstance(value, list) or isinstance(value, tuple)


@lift
def is_str(value):
    """Must be of type `str`"""
    return isinstance(value, str)

@lift
def is_str_or_coll(value):
    """
    Colors must be either a hex string or collection of RGB values.
    e.g.
        Hex string: #fff0ce
        RGB Collection: [0, 255, 128] or (0, 255, 128)
    """
    return bool(is_str(value)) or bool(is_tuple_or_list(value))


@lift
def has_valid_channel_values(rgb_coll):
    """Colors in an RGB collection must all be in the range 0-255"""
    return all([is_0to255(c) and is_int(c) for c in rgb_coll])


@lift
def is_three_channeled(value):
    """Missing channels! Colors in an RGB collection should be of the form [R,G,B] or (R,G,B)"""
    return len(value) == 3

@lift
def is_hex_string(value: str):
    """Invalid hexadecimal format. Expected: "#FFFFFF" """
    return isinstance(value, str) and bool(re.match('^#[\dABCDEF]{6}$', value, flags=2))


@lift
def is_bool(value):
    """Must be of type Boolean"""
    return isinstance(value, bool)

@lift
def non_empty_string(value):
    """Must be a non-empty non-blank string"""
    return value and bool(value.strip())

@lift
def is_tokenization_operator(value):
    """Operator must be a valid OperatorType i.e. one of: (AND, OR)"""
    return value in (OperatorType.AND, OperatorType.OR)

@lift
def is_tokenizer(value):
    """Tokenizers must be valid Regular expressions. see: options.PrefixTokenizers"""
    return bool(non_empty_string(value))


@lift
def is_int(value):
    """Invalid type. Expected `int`"""
    return isinstance(value, int)

@lift
def is_0to255(value):
    """RGB values must be in the range 0 - 255 (inclusive)"""
    return 0 <= value <= 255


def is_0to20(value):
    """Precision values must be in the range 0 - 20 (inclusive)"""
    return 0 <= value <= 20

@lift
def is_valid_color(value):
    """Must be either a valid hex string or RGB list"""
    if is_str(value):
        return is_hex_string(value)
    elif is_tuple_or_list(value):
        return (is_tuple_or_list(value)
                and is_three_channeled(value)
                and has_valid_channel_values(value))
    else:
        return is_str_or_coll(value)


validators = {
    'label_color': is_valid_color,
    'label_bg_color': is_valid_color,
    'help_color': is_valid_color,
    'help_bg_color': is_valid_color,
    'error_color': is_valid_color,
    'error_bg_color': is_valid_color,
    'show_label': is_bool,
    'show_help': is_bool,
    'visible': is_bool,
    'full_width': is_bool,
    'height': is_int,
    'readonly': is_bool,
    'initial_selection': is_int,
    'title': non_empty_string,
    'checkbox_label': non_empty_string,
    'placeholder': non_empty_string,
    'empty_message': non_empty_string,
    'max_size': is_int,
    'choice_tokenizer': is_tokenizer,
    'input_tokenizer': is_tokenizer,
    'ignore_case': is_bool,
    'operator': is_tokenization_operator,
    'index_suffix': is_bool,
    'wildcard': non_empty_string,
    'default_dir': non_empty_string,
    'default_file': non_empty_string,
    'default_path': non_empty_string,
    'message': non_empty_string,
    'precision': is_0to20
}



def collect_errors(predicates, m):
    return {
        k:predicates[k](v).rationale
        for k,v in m.items()
        if k in predicates and not predicates[k](v)}


def validate(pred, value):
    result = pred(value)
    if not result:
        raise ValueError(result.rationale)



if __name__ == '__main__':
    # TODO: there should be tests
    pass
    # print(validateColor((1, 'ergerg', 1234)))
    # print(validateColor(1234))
    # print(validateColor(123.234))
    # print(validateColor('123.234'))
    # print(validateColor('FFFAAA'))
    # print(validateColor('#FFFAAA'))
    # print(validateColor([]))
    # print(validateColor(()))
    # print(validateColor((1, 2)))
    # print(validateColor((1, 2, 1234)))
    # print(is_lifted(lift(is_int)))
    # print(is_lifted(is_int))
    # print(OR(is_poop, is_int)('poop'))
    # print(AND(is_poop, is_lower, is_lower)('pooP'))
    # print(OR(is_poop, is_int))
    # print(is_lifted(OR(is_poop, is_int)))
    # print(validate(is_valid_color, [255, 255, 256]))
    # print(is_valid_color('#fff000'))
    # print(is_valid_color([255, 244, 256]))
    # print(non_empty_string('asdf') and non_empty_string('asdf'))
    # validate(is_valid_color, 1234)





import os
import re
import subprocess
import sys
from functools import partial
from threading import Thread

from gooey.gui import events
from gooey.gui.pubsub import pub
from gooey.gui.util.casting import safe_float
from gooey.gui.util.taskkill import taskkill
from gooey.util.functional import unit, bind


class ProcessController(object):
    def __init__(self, progress_regex, progress_expr, hide_progress_msg,encoding, shell=True):
        self._process = None
        self.progress_regex = progress_regex
        self.progress_expr = progress_expr
        self.hide_progress_msg = hide_progress_msg
        self.encoding = encoding
        self.wasForcefullyStopped = False
        self.shell_execution = shell

    def was_success(self):
        self._process.communicate()
        return self._process.returncode == 0

    def poll(self):
        if not self._process:
            raise Exception('Not started!')
        return self._process.poll()

    def stop(self):
        if self.running():
            self.wasForcefullyStopped = True
            taskkill(self._process.pid)

    def running(self):
        return self._process and self.poll() is None

    def run(self, command):
        self.wasForcefullyStopped = False
        env = os.environ.copy()
        env["GOOEY"] = "1"
        env["PYTHONIOENCODING"] = self.encoding
        try:
            self._process = subprocess.Popen(
                command.encode(sys.getfilesystemencoding()),
                stdout=subprocess.PIPE, stdin=subprocess.PIPE,
                stderr=subprocess.STDOUT, shell=self.shell_execution, env=env)
        except:
            self._process = subprocess.Popen(
                command,
                stdout=subprocess.PIPE, stdin=subprocess.PIPE,
                stderr = subprocess.STDOUT, shell = self.shell_execution, env=env)

        t = Thread(target=self._forward_stdout, args=(self._process,))
        t.start()

    def _forward_stdout(self, process):
        '''
        Reads the stdout of `process` and forwards lines and progress
        to any interested subscribers
        '''
        while True:
            line = process.stdout.readline()
            if not line:
                break
            _progress = self._extract_progress(line)

            pub.send_message(events.PROGRESS_UPDATE, progress=_progress)
            if _progress is None or self.hide_progress_msg is False:
                pub.send_message(events.CONSOLE_UPDATE,
                                 msg=line.decode(self.encoding))
        pub.send_message(events.EXECUTION_COMPLETE)

    def _extract_progress(self, text):
        '''
        Finds progress information in the text using the
        user-supplied regex and calculation instructions
        '''
        # monad-ish dispatch to avoid the if/else soup
        find = partial(re.search, string=text.strip().decode(self.encoding))
        regex = unit(self.progress_regex)
        match = bind(regex, find)
        result = bind(match, self._calculate_progress)
        return result

    def _calculate_progress(self, match):
        '''
        Calculates the final progress value found by the regex
        '''
        if not self.progress_expr:
            return safe_float(match.group(1))
        else:
            return self._eval_progress(match)

    def _eval_progress(self, match):
        '''
        Runs the user-supplied progress calculation rule
        '''
        _locals = {k: safe_float(v) for k, v in match.groupdict().items()}
        if "x" not in _locals:
            _locals["x"] = [safe_float(x) for x in match.groups()]
        try:
            return int(eval(self.progress_expr, {}, _locals))
        except:
            return None



from argparse import ArgumentParser
from gooey import Gooey


@Gooey
def main_argparse():
    parser = ArgumentParser(description='Sum two integers.')
    parser.add_argument('integers', type=int, nargs=2, metavar=('first', 'second'))

    args = parser.parse_args()
    sum(args.integers)


if __name__ == "__main__":
    # main_argparse()
    main_argparse()


import os
from gooey import Gooey, GooeyParser


@Gooey(
    richtext_controls=True,
    program_name="图片爬虫工具",
    encoding="utf-8",
)
def main():


    settings_msg = '三大搜索引擎爬虫图像-谷歌暂不支持！'
    parser = GooeyParser(description=settings_msg)

    parser.add_argument("search_engine", metavar='请选择搜索引擎', help="BaiDu, Google, Bing",
                    choices=["百度图片", "Bing图片"], default="百度图片")
    parser.add_argument("save_root", metavar='设置保存路径', help="在选择路径下，自动新建多个文件夹保存图像", widget="DirChooser")
    parser.add_argument("img_num", metavar='输入下载数量', help="请输入1个数字", widget="TextField", default=10)
    parser.add_argument("key", metavar='请输入1个关键字', help="请输入关键字", widget="TextField", default="中国")

    args = parser.parse_args()
    args.img_num = int(args.img_num)

main()



import argparse

from gooey import Gooey, GooeyParser
import wx


@Gooey(clear_before_run=True)
def main():
    settings_msg = 'Example'
    parser = GooeyParser(description=settings_msg)

    args=parser.parse_args()
    print("Howdy")
    xs = ['1.0.7', '1.0.8.1', '1.0.8', '1.0.9', '1.0.7.1']
    print(sorted(xs))

if __name__ == '__main__':
    main()





import sys
from time import sleep
from gooey import Gooey, GooeyParser

@Gooey(progress_regex=r"^progress: (\d+)%$")
def main():
    parser = GooeyParser(prog="example_progress_bar")
    _ = parser.parse_args(sys.argv[1:])

    for i in range(100):
        print("progress: {}%".format(i+1))
        sleep(0.1)

if __name__ == "__main__":
    sys.exit(main())



import sys

from gooey import Gooey
from gooey import GooeyParser
from argparse import ArgumentParser

@Gooey(
    progress_regex=r"^progress: (-?\d+)%$",
    disable_progress_bar_animation=True,
    dump_build_config=True,
    show_success_modal=False,
    auto_start=True
)
def main():
    parser = get_parser()
    _ = parser.parse_args(sys.argv[1:])
    import time
    time.sleep(2)
    print('Success')



def get_parser():
    return GooeyParser(prog="example_progress_bar_1")

if __name__ == '__main__':
    main()




from .base_dialog import BaseDialog
from gooey.gui.three_to_four import Classes
from gooey.gui.lang.i18n import _


class TimeDlg(BaseDialog):
	def __init__(self, parent):
		super(TimeDlg, self).__init__(parent, 
			pickerClass=Classes.TimePickerCtrl,
			pickerGetter=lambda datepicker: datepicker.GetValue().FormatISOTime(),
			localizedPickerLabel=_('select_time'))



"""
Playing around with applicatives
"""
from functools import reduce


class Result(object):
    pass


class Success(Result):
    def __init__(self, value):
        self.value = value

    def apply(self, fx):
        a = 10
        return fx.map(self.value)

    def map(self, f):
        return Success(f(self.value))

    def bind(self, f):
        return f(self.value)

    def __str__(self):
        return 'Success<{}>'.format(self.value)


class Failure(Result):
    def __init__(self, err):
        self.error = err

    def map(self, f):
        return Failure(self.error)

    def bind(self, f):
        return Failure(self.error)

    def __str__(self):
        return 'Failure<{}>'.format(self.error)

    def apply(self, fx):
        if isinstance(fx, Failure):
            return Failure(self.error + fx.error)
        else:
            return self



def success(x):
    return Success(x)


def applyy(rf, rv):
    if isinstance(rf, Success) and isinstance(rv, Success):
        return rf.value(rv.value)
    elif isinstance(rf, Failure) and isinstance(rv, Failure):
        return Failure(rf.error + rv.error)
    elif isinstance(rf, Failure):
        return rf
    else:
        return rv


def bind(x, f):
    if isinstance(x, Success):
        return f(x.value)
    else:
        return x


def bindf(f):
    def inner(x):
        if isinstance(x, Success):
            return f(x.value)
        else:
            return x
    return success(inner)


def map(x, f):
    return bind(x, comp(f, success))


def comp(*funcs):
    def inner(x):
        return reduce(lambda acc, f: f(acc), funcs, x)
    return inner


def create_id(customer_id):
    if customer_id > 0:
        return success(customer_id)
    else:
        return Failure(['Customer id must be positive'])

def create_email(email):
    if '@' not in email:
        return Failure(['Must be email address'])
    else:
        return Success(email)


def is_upper(name):
    return (success(name)
            if name == name.upper()
            else Failure(['Must be uppercase']))

def not_none(name):
    return success(name) if name else Failure(["Name cannot be empty"])


def validate_person(name, email):
    r_name = create_id(name)
    r_email = create_email(email)
    return applyy(map(r_name, make_person), r_email)

def lift2(f, r1, r2):
    return r1.map(f).apply(r2)


def make_person(name):
    def _make_person(email):
        return {'person': name, 'email': email}
    return _make_person




r1 = bind(success(10), lambda x: success(x + 100))
r2 = (lambda x: success(x + 100))(10)

print(r1, r2)

# print(validate_person(-1, 'nameemail.com'))
print(lift2(make_person, create_id(2), create_email('name@email.com')))


# print(applyy(bindf(is_upper), success("bob")))




# print(Success(lambda x: x + 100).apply(success(10)))


# print(comp(int, lambda x: x + 1, str)("100"))
#
# print(map(success(100), lambda x: x + 100))
#
# print(
#     Success(10)
#         .map(lambda x: x + 1)
#         .bind(lambda x: Success(x + 1))
#         .bind(lambda x: Failure(Exception("FUCK!!!")))
#         .map(lambda x: x + 100)
#
# )



from __future__ import unicode_literals
from __future__ import print_function
import sys
from time import sleep
from gooey import Gooey, GooeyParser


@Gooey(progress_regex=r"^progress: (\d+)%$")
def main():
    parser = GooeyParser(prog="example_progress_bar_1")
    _ = parser.parse_args(sys.argv[1:])

    for i in range(100):
        print("progress: {}%".format(i + 1))
        sys.stdout.flush()
        sleep(0.1)


if __name__ == "__main__":
    sys.exit(main())


from gooey import Gooey, GooeyParser
import sys

@Gooey
def the_goo():
    goo = GooeyParser(description="Addition")
    goo.add_argument('Digit 1')
    goo.add_argument('Digit 2')

    goo.parse_args()
    digit_1 = sys.argv[2]
    digit_2 = sys.argv[3]
    print(digit_1)
    print(digit_2)
    print(f"{digit_1} + {digit_2} = ", int(digit_1) + int(digit_2))

the_goo()





import re

import pygtrie as trie
from functools import reduce

__ALL__ = ('PrefixTokenizers', 'PrefixSearch')



class PrefixTokenizers:
    # This string here is just an arbitrary long string so that
    # re.split finds no matches and returns the entire phrase
    ENTIRE_PHRASE = '::gooey/tokenization/entire-phrase'
    # \s == any whitespace character
    WORDS = r'\s'

    @classmethod
    def REGEX(cls, expression):
        return expression

class OperatorType:
    AND = 'AND'
    OR = 'OR'

class SearchOptions:
    def __init__(self,
                 choice_tokenizer=PrefixTokenizers.ENTIRE_PHRASE,
                 input_tokenizer=PrefixTokenizers.ENTIRE_PHRASE,
                 ignore_case=True,
                 operator='AND',
                 index_suffix= False,
                 **kwargs):
        self.choice_tokenizer = choice_tokenizer
        self.input_tokenizer = input_tokenizer
        self.ignore_case = ignore_case
        self.operator = operator
        self.index_suffix = index_suffix



class PrefixSearch(object):
    """
    A trie backed index for quickly finding substrings
    in a list of options.
    """

    def __init__(self, choices, options={}, *args, **kwargs):
        self.choices = sorted(filter(None, choices))
        self.options: SearchOptions = SearchOptions(**options)
        self.searchtree = self.buildSearchTrie(choices)

    def updateChoices(self, choices):
        self.choices = sorted(filter(None, choices))
        self.searchtree = trie.Trie()

    def findMatches(self, token):
        if not token:
            return sorted(self.choices)
        tokens = self.tokenizeInput(token)
        matches = [set(flatten(self._vals(self.searchtree, prefix=t))) for t in tokens]
        op = intersection if self.options.operator == 'AND' else union
        return sorted(reduce(op, matches))

    def tokenizeInput(self, token):
        """
        Cleans and tokenizes the user's input.

        empty characters and spaces are trimmed to prevent
        matching all paths in the index.
        """
        return list(filter(None, re.split(self.options.input_tokenizer, self.clean(token))))

    def tokenizeChoice(self, choice):
        """
        Splits the `choice` into a series of tokens based on
        the user's criteria.

        If suffix indexing is enabled, the individual tokens
        are further broken down and indexed by their suffix offsets. e.g.

            'Banana', 'anana', 'nana', 'ana'
        """
        choice_ = self.clean(choice)
        tokens = re.split(self.options.choice_tokenizer, choice_)
        if self.options.index_suffix:
            return [token[i:]
                    for token in tokens
                    for i in range(len(token) - 2)]
        else:
            return tokens

    def clean(self, text):
        return text.lower() if self.options.ignore_case else text

    def buildSearchTrie(self, choices):
        searchtrie = trie.Trie()
        for choice in choices:
            for token in self.tokenizeChoice(choice):
                if not searchtrie.has_key(token):
                    searchtrie[token] = []
                searchtrie[token].append(choice)
        return searchtrie

    def _vals(self, searchtrie, **kwargs):
        try:
            return searchtrie.values(**kwargs)
        except KeyError:
            return []


def intersection(a, b):
    return a.intersection(b)


def union(a, b):
    return a.union(b)


def flatten(xs):
    return [item for x in xs for item in x]



import unittest
from argparse import ArgumentParser
from unittest.mock import patch

from gooey import GooeyParser
from tests.harness import instrumentGooey
from gooey.tests import *

class TestGooeyDropdown(unittest.TestCase):

    def makeParser(self, **kwargs):
        parser = GooeyParser(description='description')
        parser.add_argument('--dropdown', **kwargs)
        return parser


    @patch("gui.containers.application.seeder.fetchDynamicProperties")
    def test_dropdown_behavior(self, mock):
        """
        Testing that:
            - default values are used as the initial selection (when present)
            - Initial selection defaults to placeholder when no defaults supplied
            - selection is preserved (when possible) across dynamic updates
        """
        testcases = [
            # tuples of [choices, default, initalSelection, dynamicUpdate, expectedFinalSelection]
            [['1', '2'], None, 'Select Option', ['1', '2','3'], 'Select Option'],
            [['1', '2'], '2', '2', ['1', '2','3'],  '2'],
            [['1', '2'], '1', '1', ['1', '2','3'], '1'],
            # dynamic updates removed our selected value; defaults back to placeholder
            [['1', '2'], '2', '2', ['1', '3'], 'Select Option'],
            # TODO: this test case is currently passing wrong data for the dynamic
            # TODO: update due to a bug where Gooey doesn't apply the same ingestion
            # TODO: rules for data received dynamically as it does for parsers.
            # TODO: In short, Gooey should be able to handle a list of bools [True, False]
            # TODO: from dynamics just like it does in parser land. It doesn't currently
            # TODO: do this, so I'm manually casting it to strings for now.
            [[True, False], True, 'True', ['True', 'False'], 'True']
        ]

        for choices, default, initalSelection, dynamicUpdate, expectedFinalSelection in testcases:
            parser = self.makeParser(choices=choices, default=default)
            with instrumentGooey(parser) as (app, gooeyApp):
                dropdown = gooeyApp.configs[0].reifiedWidgets[0]
                # ensure that default values (when supplied) are selected in the UI
                self.assertEqual(dropdown.widget.GetValue(), initalSelection)
                # fire a dynamic update with the mock values
                mock.return_value = {'--dropdown': dynamicUpdate}
                gooeyApp.fetchExternalUpdates()
                # the values in the UI now reflect those returned from the update
                # note: we're appending the ['select option'] bit here as it gets automatically added
                # in the UI.
                expectedValues = ['Select Option'] + dynamicUpdate
                self.assertEqual(dropdown.widget.GetItems(), expectedValues)
                # and our selection is what we expect
                self.assertEqual(dropdown.widget.GetValue(), expectedFinalSelection)


    def testInitialValue(self):
        cases = [
            # `initial` should supersede `default`
            {'inputs': {'default': 'b',
                        'choices': ['a', 'b', 'c'],
                        'gooey_options': {'initial_value': 'a'}},
             'expect': 'a'},

            {'inputs': {'choices': ['a', 'b', 'c'],
                        'gooey_options': {'initial_value': 'a'}},
             'expect': 'a'},

            {'inputs': {'choices': ['a', 'b', 'c'],
                        'default': 'b',
                        'gooey_options': {}},
             'expect': 'b'},

            {'inputs': {'choices': ['a', 'b', 'c'],
                        'default': 'b'},
             'expect': 'b'},

            {'inputs': {'choices': ['a', 'b', 'c']},
             'expect': None}
        ]
        for case in cases:
            with self.subTest(case):
                parser = self.makeParser(**case['inputs'])
                with instrumentGooey(parser) as (app, gooeyApp):
                    widget = gooeyApp.configs[0].reifiedWidgets[0]
                    self.assertEqual(widget.getValue()['rawValue'], case['expect'])


if __name__ == '__main__':
    unittest.main()


from gooey import Gooey, GooeyParser


@Gooey(language='chinese')
def main():
    parser = GooeyParser()
    parser.add_argument('filename1')
    parser.add_argument('filename2')
    parser.add_argument('-f', '--foobar')
    args = parser.parse_args()


if __name__ == '__main__':
    main()


import sys
import os
import signal


if sys.platform.startswith("win"):
  def taskkill(pid):
    os.system('taskkill /F /PID {:d} /T >NUL 2>NUL'.format(pid))
else:  # POSIX
  import psutil
  def taskkill(pid):
    parent = psutil.Process(pid)
    for child in parent.children(recursive=True):
      child.kill()
    parent.kill()



from gooey import Gooey, GooeyParser
import argparse

@Gooey
def main():
    cli = GooeyParser(description='Utils')
    required_args = cli.add_argument_group("Required Arguments")
    required_args.add_argument(
        '-i', '--in', required=True, metavar='PATH', dest='inpath'
    )
    required_args.add_argument(
        '-o', '--out', required=True, metavar='PATH', dest='outpath'
    )

    advanced_section = cli.add_argument_group(
        "Advanced Options",
        description='Change these options at your own risk!!!',
        gooey_options={
            'show_border': True
        }
    )

    advanced_section.add_argument('--dont-destroy-computer',
                                  help='When enabled this will NOT cause an explosion',
                                  metavar="Avoid Violently Delf Destruct",
                                  action='store_true',
                                  widget='BlockCheckbox',
                                  default=True)
    args = cli.parse_args()

if __name__ == '__main__':
    main()


import sys
from enum import Enum
from gooey import Gooey, GooeyParser

class TestMode(Enum):
    PRODUCTION = 0
    VALIDATION = 1
    TEST = 2
    NONE = 3

@Gooey()
def main() -> int:
    parser = GooeyParser(description="Show unexpected behaviour")

    parser.set_defaults(mode=TestMode.PRODUCTION)
    mode = parser.add_mutually_exclusive_group()

    mode.add_argument(
        "--none",
        metavar="None",
        action="store_const",
        const=TestMode.NONE,
        help="Don't use any special validation logic",
    )

    mode.add_argument(
        "--validation",
        metavar="Validation",
        action="store_const",
        const=TestMode.VALIDATION,
        help="Target the validation database.",
    )
    mode.add_argument(
        "--test",
        metavar="Test",
        dest="mode",
        action="store_const",
        const=TestMode.TEST,
        help="Target the test database.",
    )

    print(parser.parse_args())

main()


from gooey import Gooey, GooeyParser
import sys

@Gooey
def the_blob():
    blob = GooeyParser(description="Subtraction")
    blob.add_argument('Digit 1')
    blob.add_argument('Digit 2')

    blob.parse_args()
    digit_1 = sys.argv[2]
    digit_2 = sys.argv[3]
    print(digit_1)
    print(digit_2)
    print(f"{digit_1} - {digit_2} = ", int(digit_1) - int(digit_2))

the_blob()





'''
Util for supporting WxPython 3 & 4
'''

import wx
try:
    import wx.adv
except ImportError:
    pass

isLatestVersion = wx.version().startswith('4')


class Constants:
    if isLatestVersion:
        WX_FONTSTYLE_NORMAL = wx.FONTSTYLE_NORMAL
        WX_DP_DROPDOWN = wx.adv.DP_DROPDOWN
    else:
        WX_FONTSTYLE_NORMAL = wx.FONTWEIGHT_NORMAL
        WX_DP_DROPDOWN = wx.DP_DROPDOWN


class Classes:
    if isLatestVersion:
        DatePickerCtrl = wx.adv.DatePickerCtrl
    else:
        DatePickerCtrl = wx.DatePickerCtrl

    if isLatestVersion:
        TimePickerCtrl = wx.adv.TimePickerCtrl
    else:
        TimePickerCtrl = wx.TimePickerCtrl




def imageFromBitmap(bitmap):
    if isLatestVersion:
        return bitmap.ConvertToImage()
    else:
        return wx.ImageFromBitmap(bitmap)


def bitmapFromImage(image):
    if isLatestVersion:
        return wx.Bitmap(image)
    else:
        return wx.BitmapFromImage(image)


def bitmapFromBufferRGBA(im, rgba):
    if isLatestVersion:
        return wx.Bitmap.FromBufferRGBA(im.size[0], im.size[1], rgba)
    else:
        return wx.BitmapFromBufferRGBA(im.size[0], im.size[1], rgba)

def AboutDialog():
    if isLatestVersion:
        return wx.adv.AboutDialogInfo()
    else:
        return wx.AboutDialogInfo()


def AboutBox(aboutDialog):
    return (wx.adv.AboutBox(aboutDialog)
            if isLatestVersion
            else wx.AboutBox(aboutDialog))




import time
import unittest

from tests.integration.programs import validations as validations_module


class TestGooeyIntegration(unittest.TestCase):
    """
    A few quick integration tests that exercise Gooey's various run modes

    WX Python needs to control the main thread. So, in order to simulate a user
    running through the system, we have to execute the actual assertions in a
    different thread
    """

    def test__gooeyValidation(self):
        """Verifies that custom validation routines supplied via gooey_options prevents
        the user from advancing past the configuration page when they fail"""
        from gooey.tests.integration import runner
        runner.run_integration(validations_module, self.verifyValidators)


    def verifyValidators(self, app, buildSpec):
        time.sleep(1)
        try:
            app.TopWindow.onStart()
            title = app.TopWindow.header._header.GetLabel()
            subtitle = app.TopWindow.header._subheader.GetLabel()
            self.assertNotEqual(title, buildSpec['program_name'])
            self.assertNotEqual(subtitle, buildSpec['program_description'])
        except:
            app.TopWindow.Destroy()
            raise
        else:
            import wx
            wx.CallAfter(app.TopWindow.Destroy)
            return None



if __name__ == '__main__':
    unittest.main()









import wx

from gooey.gui.util import wx_util


class Sidebar(wx.Panel):
    """
    Sidebar handles the show/hide logic so that it mirrors the functionality
    of the wx.Notebook class (which wants to control everything)
    """
    def __init__(self, parent, buildSpec, configPanels, *args, **kwargs):
        super(Sidebar, self).__init__(parent, *args, **kwargs)
        self._parent = parent
        self.buildSpec = buildSpec
        self.configPanels = configPanels
        self.activeSelection = 0
        self.options = list(self.buildSpec['widgets'].keys())
        self.leftPanel = wx.Panel(self)
        self.label = wx_util.h1(self.leftPanel, self.buildSpec.get('sidebar_title'))
        self.listbox = wx.ListBox(self.leftPanel, -1, choices=self.options)
        self.Bind(wx.EVT_LISTBOX, self.swapConfigPanels, self.listbox)
        self.layoutComponent()
        self.listbox.SetSelection(0)


    def getSelectedGroup(self):
        """Return the currently active 'group' i.e. the root SubParser """
        return self.options[self.activeSelection]


    def getActiveConfig(self):
        """Return the currently visible config screen"""
        return self.configPanels[self.activeSelection]


    def swapConfigPanels(self, event):
        """Hide/show configuration panels based on the currently selected
         option in the sidebar """
        for id, panel in enumerate(self.configPanels):
            panel.Hide()
        self.activeSelection = event.Selection
        self.configPanels[event.Selection].Show()
        self._parent.Layout()


    def layoutComponent(self):
        left = self.layoutLeftSide()

        hsizer = wx.BoxSizer(wx.HORIZONTAL)
        hsizer.Add(left, 0, wx.EXPAND)

        if not self.buildSpec['tabbed_groups']:
            # only add it for non-tabbed layouts as it looks
            # weird against the tabbed ones
            hsizer.Add(wx_util.vertical_rule(self), 0, wx.EXPAND)

        for body in self.configPanels:
            body.Reparent(self)
            hsizer.Add(body, 1, wx.EXPAND)
            body.Hide()
        self.configPanels[0].Show()
        self.SetSizer(hsizer)

        if not self.buildSpec['show_sidebar']:
            left.Show(False)

        self.Layout()


    def layoutLeftSide(self):
        self.leftPanel.SetBackgroundColour(self.buildSpec['sidebar_bg_color'])
        self.leftPanel.SetSize((180, 0))
        self.leftPanel.SetMinSize((180, 0))

        container = wx.BoxSizer(wx.VERTICAL)
        container.AddSpacer(15)
        container.Add(self.label, 0, wx.LEFT | wx.RIGHT | wx.EXPAND, 10)
        container.AddSpacer(5)

        container.Add(self.listbox, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 10)
        container.AddSpacer(20)
        self.leftPanel.SetSizer(container)
        return self.leftPanel






from itertools import chain

from copy import deepcopy

from gooey.util.functional import compact


def buildCliString(target, cmd, positional, optional, suppress_gooey_flag=False):
    positionals = deepcopy(positional)
    if positionals:
        positionals.insert(0, "--")

    cmd_string = ' '.join(compact(chain(optional, positionals)))

    if cmd != '::gooey/default':
        cmd_string = u'{} {}'.format(cmd, cmd_string)

    ignore_flag = '' if suppress_gooey_flag else '--ignore-gooey'
    return u'{} {} {}'.format(target, ignore_flag, cmd_string)



import os

import itertools

from gooey.gui.util.quoting import quote


def checkbox(metadata, value):
    return metadata['commands'][0] if value else None


def radioGroup(metadata, value):
    # TODO
    try:
        return self.commands[self._value.index(True)][0]
    except ValueError:
        return None


def multiFileChooser(metadata, value):
    paths = ' '.join(quote(x) for x in value.split(os.pathsep) if x)
    if metadata['commands'] and paths:
        return u'{} {}'.format(metadata['commands'][0], paths)
    return paths or None


def textArea(metadata, value):
    if metadata['commands'] and value:
        return '{} {}'.format(metadata['commands'][0], quote(value.encode('unicode_escape')))
    else:
        return quote(value.encode('unicode_escape')) if value else ''


def commandField(metadata, value):
    if metadata['commands'] and value:
        return u'{} {}'.format(metadata['commands'][0], value)
    else:
        return value or None


def counter(metatdata, value):
    '''
    Returns
      str(option_string * DropDown Value)
      e.g.
      -vvvvv
    '''
    if not str(value).isdigit():
        return None
    command = str(metatdata['commands'][0]).strip()
    return ' '.join(itertools.repeat(command, int(value)))


def dropdown(metadata, value):
    if value == 'Select Option':
        return None
    elif metadata['commands'] and value:
        return u'{} {}'.format(metadata['commands'][0], quote(value))
    else:
        return quote(value) if value else ''


def listbox(meta, value):
    if meta['commands'] and value:
        return u'{} {}'.format(meta['commands'][0], ' '.join(map(quote, value)))
    else:
        return ' '.join(map(quote, value)) if value else ''


def general(metadata, value):
    if metadata.get('commands') and value:
        if not metadata.get('nargs'):
            v = quote(value)
        else:
            v = value
        return u'{0} {1}'.format(metadata['commands'][0], v)
    else:
        if not value:
            return None
        elif not metadata.get('nargs'):
            return quote(value)
        else:
            return value




import unittest

from tests.harness import instrumentGooey
from gooey import GooeyParser
from gooey.tests import *



class TestListbox(unittest.TestCase):

    def makeParser(self, **kwargs):
        parser = GooeyParser(description='description')
        parser.add_argument(
            '--widget',
            widget="Listbox",
            nargs="*",
            **kwargs)
        return parser

    def testInitialValue(self):
        cases = [
            # `initial` should supersede `default`
            {'inputs': {'default': 'b',
                        'choices': ['a', 'b', 'c'],
                        'gooey_options': {'initial_value': 'a'}},
             'expect': ['a']},

            {'inputs': {'choices': ['a', 'b', 'c'],
                        'gooey_options': {'initial_value': 'a'}},
             'expect': ['a']},

            {'inputs': {'choices': ['a', 'b', 'c'],
                        'gooey_options': {'initial_value': ['a', 'c']}},
             'expect': ['a', 'c']},

            {'inputs': {'choices': ['a', 'b', 'c'],
                        'default': 'b',
                        'gooey_options': {}},
             'expect': ['b']},

            {'inputs': {'choices': ['a', 'b', 'c'],
                        'default': 'b'},
             'expect': ['b']},

            {'inputs': {'choices': ['a', 'b', 'c']},
             'expect': []}
        ]
        for case in cases:
            with self.subTest(case):
                parser = self.makeParser(**case['inputs'])
                with instrumentGooey(parser) as (app, gooeyApp):
                    widget = gooeyApp.configs[0].reifiedWidgets[0]
                    self.assertEqual(widget.getValue()['rawValue'], case['expect'])



if __name__ == '__main__':
    unittest.main()


import wx
import sys
import time

from gooey import Gooey, GooeyParser, constants


@Gooey
def gooey_app():
    parser = GooeyParser()

    group = parser.add_mutually_exclusive_group(required=False, gooey_options={
        'initial_selection': 0
    })
    group.add_argument('-f', '--file', help="Chose a File")
    group.add_argument('-d', '--dir', help="Chose a directory")


    args = parser.parse_args()


if __name__ == '__main__':
    sys.exit(gooey_app())


import sys
import argparse
from gooey import Gooey


@Gooey
def main():
    """Demonstrate [metavar='<FILE>', type=argparse.FileType()] issue."""
    parser = argparse.ArgumentParser(
        description="Show [metavar='<FILE>', type=argparse.FileType()] issue.",
        add_help=False,
        usage="test.py -u username -p password [options]")
    parser.add_argument('-o',
                        metavar='<FILE>',
                        type=argparse.FileType('w'),
                        default=sys.stdout,
                        help='output data file [stdout]')

    args = parser.parse_args()
    print(args.o)
    for i in range(10):
        args.o.write(str(i))


if __name__ == '__main__':
    main()


import sys
import time

from gooey import Gooey, GooeyParser


@Gooey(show_stop_warning=False)
def gooey_app():
    parser = GooeyParser()
    args = parser.parse_args()

    # Do something for a long time
    for i in range(100):
        time.sleep(1)

    return 0

if __name__ == '__main__':
    sys.exit(gooey_app())


'''
Created on Jan 24, 2014

@author: Chris

TODO: this
'''

import json
import os
import sys
from argparse import ArgumentParser

from gooey.gui.util.freeze import getResourcePath
from gooey.util.functional import merge
from . import config_generator
from . import cmd_args

IGNORE_COMMAND = '--ignore-gooey'

# TODO: use these defaults in the decorator and migrate to a flat **kwargs
#       They're pulled out here for wiring up instances in the tests.
#       Some fiddling is needed before I can make the changes to make the swap to
#       `defaults` + **kwargs overrides.
defaults = {
    'advanced': True,
    'language': 'english',
    'auto_start': False,  # TODO: add this to the docs. Used to be `show_config=True`
    'target': None,
    'program_name': None,
    'program_description': None,
    'default_size': (610, 530),
    'use_legacy_titles': True,
    'required_cols': 2,
    'optional_cols': 2,
    'dump_build_config': False,
    'load_build_config': None,
    'monospace_display': False,  # TODO: add this to the docs
    'image_dir': '::gooey/default',
    'language_dir': getResourcePath('languages'),
    'progress_regex': None,  # TODO: add this to the docs
    'progress_expr': None,  # TODO: add this to the docs
    'hide_progress_msg': False,  # TODO: add this to the docs
    'disable_progress_bar_animation': False,
    'disable_stop_button': False,
    'group_by_type': True,
    'header_height': 80,
    'navigation': 'SIDEBAR', # TODO: add this to the docs
    'tabbed_groups': False,
    'use_cmd_args': False,
    'timing_options': {
      'show_time_remaining': False,
      'hide_time_remaining_on_complete': True
    }
}

# TODO: kwargs all the things
def Gooey(f=None,
          advanced=True,
          language='english',
          auto_start=False,  # TODO: add this to the docs. Used to be `show_config=True`
          target=None,
          program_name=None,
          program_description=None,
          default_size=(610, 530),
          use_legacy_titles=True,
          required_cols=2,
          optional_cols=2,
          dump_build_config=False,
          load_build_config=None,
          monospace_display=False,  # TODO: add this to the docs
          image_dir='::gooey/default',
          language_dir=getResourcePath('languages'),
          progress_regex=None,  # TODO: add this to the docs
          progress_expr=None,  # TODO: add this to the docs
          hide_progress_msg=False,  # TODO: add this to the docs
          disable_progress_bar_animation=False,
          disable_stop_button=False,
          group_by_type=True,
          header_height=80,
          navigation='SIDEBAR', # TODO: add this to the docs
          tabbed_groups=False,
          use_cmd_args=False,
          **kwargs):
  '''
  Decorator for client code's main function.
  Serializes argparse data to JSON for use with the Gooey front end
  '''

  params = merge(locals(), locals()['kwargs'])

  def build(payload):
    def run_gooey(self, args=None, namespace=None):
      # This import is delayed so it is not in the --ignore-gooey codepath.
      from gooey.gui import application
      source_path = sys.argv[0]

      build_spec = None
      if load_build_config:
        try:
          exec_dir = os.path.dirname(sys.argv[0])
          open_path = os.path.join(exec_dir,load_build_config)
          build_spec = json.load(open(open_path, "r"))
        except Exception as e:
          print('Exception loading Build Config from {0}: {1}'.format(load_build_config, e))
          sys.exit(1)

      if not build_spec:
        if use_cmd_args:
          cmd_args.parse_cmd_args(self, args)

        build_spec = config_generator.create_from_parser(
          self,
          source_path,
          payload_name=payload.__name__,
          **params)

      if dump_build_config:
        config_path = os.path.join(os.path.dirname(sys.argv[0]), 'gooey_config.json')
        print('Writing Build Config to: {}'.format(config_path))
        with open(config_path, 'w') as f:
          f.write(json.dumps(build_spec, indent=2))
      application.run(build_spec)

    def inner2(*args, **kwargs):
      ArgumentParser.original_parse_args = ArgumentParser.parse_args
      ArgumentParser.parse_args = run_gooey
      return payload(*args, **kwargs)

    inner2.__name__ = payload.__name__
    return inner2

  def run_without_gooey(func):
    return lambda *args, **kwargs: func(*args, **kwargs)

  if IGNORE_COMMAND in sys.argv:
    sys.argv.remove(IGNORE_COMMAND)
    if callable(f):
      return run_without_gooey(f)
    return run_without_gooey

  if callable(f):
    return build(f)
  return build


if __name__ == '__main__':
  pass



from rx.subjects import Subject
from rx.concurrency import QtScheduler
import sys

try:
    from PyQt4 import QtCore
    from PyQt4.QtGui import QWidget, QLabel
    from PyQt4.QtGui import QApplication
except ImportError:
    try:
        from PyQt5 import QtCore
        from PyQt5.QtWidgets import QApplication, QWidget, QLabel
    except ImportError:
        from PySide import QtCore
        from PySide.QtGui import QWidget, QLabel
        from PySide.QtGui import QApplication


class Window(QWidget):

    def __init__(self):
        super(QWidget, self).__init__()
        self.setWindowTitle("Rx for Python rocks")
        self.resize(600, 600)
        self.setMouseTracking(True)

        # This Subject is used to transmit mouse moves to labels
        self.mousemove = Subject()

    def mouseMoveEvent(self, event):
        self.mousemove.on_next((event.x(), event.y()))


def main():
    app = QApplication(sys.argv)
    scheduler = QtScheduler(QtCore)

    window = Window()
    window.show()

    text = 'TIME FLIES LIKE AN ARROW'
    labels = [QLabel(char, window) for char in text]

    def handle_label(i, label):

        def on_next(pos):
            x, y = pos
            label.move(x + i*12 + 15, y)
            label.show()

        window.mousemove.delay(i*100, scheduler=scheduler).subscribe(on_next)

    for i, label in enumerate(labels):
        handle_label(i, label)

    sys.exit(app.exec_())

if __name__ == '__main__':
    main()





# surprising Python behavior

def foo():

    funcs = []

    for i in range(10):
        funcs.append(lambda x: print('x', i))

    for func in funcs:
        func("yo")

foo()

def thingieMcThingFace():
    def f(x)







'''
Created on Dec 23, 2013

@author: Chris
'''

import wx

from gooey.gui import imageutil, image_repository
from gooey.gui.util import wx_util
from gooey.gui.three_to_four import bitmapFromImage
from gooey.util.functional import getin
from gooey.gui.components.mouse import notifyMouseEvent

PAD_SIZE = 10


class FrameHeader(wx.Panel):
    def __init__(self, parent, buildSpec, **kwargs):
        wx.Panel.__init__(self, parent, **kwargs)
        self.SetDoubleBuffered(True)

        self.buildSpec = buildSpec

        self._header = None
        self._subheader = None
        self.settings_img = None
        self.running_img = None
        self.check_mark = None
        self.error_symbol = None

        self.images = []

        self.layoutComponent()
        self.bindMouseEvents()



    def setTitle(self, title):
        self._header.SetLabel(title)

    def setSubtitle(self, subtitle):
        self._subheader.SetLabel(subtitle)

    def setImage(self, image):
        for img in self.images:
            img.Show(False)
        getattr(self, image).Show(True)
        self.Layout()

    def layoutComponent(self):
        self.SetBackgroundColour(self.buildSpec['header_bg_color'])
        self.SetSize((30, self.buildSpec['header_height']))
        self.SetMinSize((120, self.buildSpec['header_height']))

        self._header = wx_util.h1(self, label=self.buildSpec['program_name'])
        self._subheader = wx.StaticText(self, label=self.buildSpec['program_description'])

        images = self.buildSpec['images']
        targetHeight = self.buildSpec['header_height'] - 10
        self.settings_img = self._load_image(images['configIcon'], targetHeight)
        self.running_img = self._load_image(images['runningIcon'], targetHeight)
        self.check_mark = self._load_image(images['successIcon'], targetHeight)
        self.error_symbol = self._load_image(images['errorIcon'], targetHeight)

        self.images = [
            self.settings_img,
            self.running_img,
            self.check_mark,
            self.error_symbol
        ]

        vsizer = wx.BoxSizer(wx.VERTICAL)
        sizer = wx.BoxSizer(wx.HORIZONTAL)
        headings_sizer = self.build_heading_sizer()
        sizer.Add(headings_sizer, 1,
                  wx.ALIGN_LEFT | wx.EXPAND | wx.LEFT,
                  PAD_SIZE)
        sizer.Add(self.settings_img, 0, wx.EXPAND | wx.RIGHT, PAD_SIZE)
        sizer.Add(self.running_img, 0, wx.EXPAND | wx.RIGHT, PAD_SIZE)
        sizer.Add(self.check_mark, 0, wx.EXPAND | wx.RIGHT, PAD_SIZE)
        sizer.Add(self.error_symbol, 0, wx.EXPAND | wx.RIGHT, PAD_SIZE)
        self.running_img.Hide()
        self.check_mark.Hide()
        self.error_symbol.Hide()
        vsizer.Add(sizer, 1, wx.EXPAND)
        self.SetSizer(vsizer)


    def _load_image(self, imgPath, targetHeight):
        rawImage = imageutil.loadImage(imgPath)
        sizedImage = imageutil.resizeImage(rawImage, targetHeight)
        return imageutil.wrapBitmap(sizedImage, self)


    def build_heading_sizer(self):
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.AddStretchSpacer(1)
        if self.buildSpec['header_show_title']:
            sizer.Add(self._header, 0)
        else:
            self._header.Hide()

        if self.buildSpec['header_show_subtitle']:
            sizer.Add(self._subheader, 0)
        else:
            self._subheader.Hide()
        sizer.AddStretchSpacer(1)
        return sizer

    def bindMouseEvents(self):
        """
        Manually binding all LEFT_DOWN events.
        See: gooey.gui.mouse for background.
        """
        self.Bind(wx.EVT_LEFT_DOWN, notifyMouseEvent)
        self._header.Bind(wx.EVT_LEFT_DOWN, notifyMouseEvent)
        self._subheader.Bind(wx.EVT_LEFT_DOWN, notifyMouseEvent)
        for image in self.images:
            image.Bind(wx.EVT_LEFT_DOWN, notifyMouseEvent)


"""
An example of a Model-View-Controller architecture,
using wx.lib.pubsub to handle proper updating of widget (View) values.
"""
import wx
from gooey.gui.pubsub import pub

class Model:
    def __init__(self):
        self.myMoney = 0

    def addMoney(self, value):
        self.myMoney += value
        #now tell anyone who cares that the value has been changed
        pub.send_message("MONEY CHANGED", message=self.myMoney)

    def removeMoney(self, value):
        self.myMoney -= value
        #now tell anyone who cares that the value has been changed
        pub.send_message("MONEY CHANGED", message=self.myMoney)

class View(wx.Frame):
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, title="Main View")

        sizer = wx.BoxSizer(wx.VERTICAL)
        text = wx.StaticText(self, label="My Money")
        ctrl = wx.TextCtrl(self)
        sizer.Add(text, 0, wx.EXPAND | wx.ALL)
        sizer.Add(ctrl, 0, wx.EXPAND | wx.ALL)

        self.moneyCtrl = ctrl
        ctrl.SetEditable(False)
        self.SetSizer(sizer)

    def SetMoney(self, money):
        self.moneyCtrl.SetValue(str(money))

class ChangerWidget(wx.Frame):
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, title="Main View")

        sizer = wx.BoxSizer(wx.VERTICAL)
        self.add = wx.Button(self, label="Add Money")
        self.remove = wx.Button(self, label="Remove Money")
        sizer.Add(self.add, 0, wx.EXPAND | wx.ALL)
        sizer.Add(self.remove, 0, wx.EXPAND | wx.ALL)
        self.SetSizer(sizer)

class Controller:
    def __init__(self, app):
        self.model = Model()

        #set up the first frame which displays the current Model value
        self.view1 = View(None)
        self.view1.SetMoney(self.model.myMoney)

        #set up the second frame which allows the user to modify the Model's value
        self.view2 = ChangerWidget(self.view1)
        self.view2.add.Bind(wx.EVT_BUTTON, self.AddMoney)
        self.view2.remove.Bind(wx.EVT_BUTTON, self.RemoveMoney)
        #subscribe to all "MONEY CHANGED" messages from the Model
        #to subscribe to ALL messages (topics), omit the second argument below
        pub.subscribe(self.MoneyChanged, "MONEY CHANGED")

        self.view1.Show()
        self.view2.Show()

    def AddMoney(self, evt):
        self.model.addMoney(10)

    def RemoveMoney(self, evt):
        self.model.removeMoney(10)

    def MoneyChanged(self, message):
        """
        This method is the handler for "MONEY CHANGED" messages,
        which pubsub will call as messages are sent from the model.

        We already know the topic is "MONEY CHANGED", but if we
        didn't, message.topic would tell us.
        """
        self.view1.SetMoney(message)

if __name__ == "__main__":
    app = wx.App(False)
    controller = Controller(app)
    app.MainLoop()



import unittest
from collections import namedtuple

from tests.harness import instrumentGooey
from gooey import GooeyParser
from gooey.tests import *

Case = namedtuple('Case', 'inputs initialExpected expectedAfterClearing')

class TestTextField(unittest.TestCase):

    def makeParser(self, **kwargs):
        parser = GooeyParser(description='description')
        parser.add_argument('--widget', widget="TextField", **kwargs)
        return parser


    def testPlaceholder(self):
        cases = [
            [{}, ''],
            [{'placeholder': 'Hello'}, 'Hello']
        ]
        for options, expected in cases:
            parser = self.makeParser(gooey_options=options)
            with instrumentGooey(parser) as (app, gooeyApp):
                # because of how poorly designed the Gooey widgets are
                # we have to reach down 3 levels in order to find the
                # actual WX object we need to test.
                widget = gooeyApp.configs[0].reifiedWidgets[0].widget
                self.assertEqual(widget.widget.GetHint(), expected)




    def testDefaultAndInitialValue(self):
        cases = [
            # initial_value takes precedence when both are present
            Case(
                {'default': 'default_val', 'gooey_options': {'initial_value': 'some val'}},
                'some val',
                None),
            # when no default is present
            # Case({'gooey_options': {'initial_value': 'some val'}},
            #  'some val',
            #  ''),
            # [{'default': 'default', 'gooey_options': {}},
            #  'default'],
            # [{'default': 'default'},
            #  'default'],
        ]
        for case in cases:
            parser = self.makeParser(**case.inputs)
            with instrumentGooey(parser) as (app, gooeyApp):
                widget = gooeyApp.configs[0].reifiedWidgets[0]
                self.assertEqual(widget.getValue()['rawValue'], case.initialExpected)
                widget.setValue('')
                print(widget.getValue())
                self.assertEqual(widget.getValue()['cmd'], case.expectedAfterClearing)

if __name__ == '__main__':
    unittest.main()


import argparse
from gooey import Gooey

@Gooey
def main():

    parser = argparse.ArgumentParser(description='Process some integers.')
    parser.add_argument('integers', metavar='N', type=int, nargs='+',
                       help='an integer for the accumulator')
    parser.add_argument('--sum', dest='accumulate', action='store_const',
                       const=sum, default=max,
                       help='sum the integers (default: find the max)')

    args = parser.parse_args()
    print( args.accumulate(args.integers))

if __name__=="__main__":
    main()


import argparse
from gooey import GooeyParser

def get_parser() -> argparse.ArgumentParser:
    parser = GooeyParser()
    parser.add_argument(
        nargs="*",
        default=["foo bar"],
        dest="multi_arg",
    )
    parser.add_argument('--foo', nargs=1, default=['a', 'b'])
    # parser.add_argument(
    #     '--bar',
    #     nargs='+',
    #     choices=["one", "two"],
    #     default="one",
    # )
    parser.add_argument('--listboxie',
                    metavar='Multiple selection',
                    nargs='+',
                    # default=['Option three', 'Option four'],
                    default='123',
                    choices=[123, 'Option two', 'Option three',
                             'Option four'],
                    help='Choose an action!',
                    widget='Listbox',
                    gooey_options={
                        # 'height': 500,
                        'validate': '',
                        'heading_color': '',
                        'text_color': '',
                        'show_label': False,
                        'hide_text': True,
                    }
                    )
    return parser


from gooey import GooeyParser, Gooey
@Gooey
def main():
    args = get_parser().parse_args()
    print(args)
    assert args.multi_arg == ["foo bar"]


if __name__ == "__main__":
    main()




def runValidator(f, value):
    """
    Attempt to run the user supplied validation function

    Fall back to False in the even of any errors
    """
    try:
        return f(value)
    except:
        return False






import sys
from pprint import pprint

from gooey import Gooey, GooeyParser

@Gooey( program_name="Using Dynamic Values")
def main():
    parser = GooeyParser()

    g = parser.add_argument_group()

    stuff = g.add_mutually_exclusive_group(
        required=True,
        gooey_options={
            'initial_selection': 0
        }
    )
    stuff.add_argument(
        '--one',
        action='store',
        # gooey_options={
        #     'validator': {
        #         'test': 'user_input',
        #         'message': 'You must supply a value when this option is selected!'
        #     }
        # }
    )
    stuff.add_argument(
        '--two',
        action='store'
    )

    args = parser.parse_args()
    pprint(args)

if __name__ == '__main__':
    print("-"*80)
    pprint(sys.argv)
    main()


import cookiecutter.main
import sys
from gooey import Gooey, GooeyParser

from utils import to_project_style


@Gooey(
    program_name='Pyramid app builder',
    program_description='Create a Pyramid web app',
    show_success_modal=False)
def main():
    print(sys.argv)
    info = get_user_values()
    proj_dir = build_app(info)

    print("Project created: {}".format(proj_dir))


def get_user_values():
    parser = GooeyParser()
    parser.add_argument(dest='template',
                        metavar='Project type',
                        help="Type of Pyramid project",
                        choices=['Starter', "Talk Python Entrepreneur's", 'SQLAlchemy', 'SubstanceD', 'ZODB'])
    parser.add_argument('project_name',
                        metavar='Project name',
                        help="The user-visible name of your project")
    parser.add_argument(
        dest='template_language',
        metavar='Template language',
        widget='Dropdown',
        choices=["jinja2", "chameleon", "mako"]
    )
    parser.add_argument(
        dest="working_dir",
        metavar='Output directory',
        help='Directory for project',
        widget="DirChooser")

    sysargs = sys.argv[1:]
    args = parser.parse_args(sysargs)
    return args


def template_to_url(template_name: str) -> str:
    if template_name == 'Starter':
        return 'https://github.com/Pylons/pyramid-cookiecutter-starter'
    elif template_name == 'SQLAlchemy':
        return 'https://github.com/Pylons/pyramid-cookiecutter-alchemy'
    elif template_name == 'SubstanceD':
        return 'https://github.com/Pylons/substanced-cookiecutter'
    elif template_name == "Talk Python Entrepreneur's":
        return 'https://github.com/mikeckennedy/cookiecutter-pyramid-talk-python-starter'
    else:
        raise Exception("Unknown template type")


def build_app(info):
    template = template_to_url(info.template)
    proj_dir = cookiecutter.main.cookiecutter(
        template,
        no_input=True,
        output_dir=info.working_dir,
        extra_context={
            'project_name': info.project_name,
            'repo_name': to_project_style(info.project_name),
            'template_language': info.template_language,
            "project_slug": to_project_style(info.project_name),
            "contact_name": "Company Name",
            "domain_name": "yourcompany.com",
            "contact_email": "contact@company.com",
            "description": "",
            "integrations": "",
            "mailchimp_api": "",
            "mailchimp_list_id": "",
            "outbound_smtp_username": "",
            "outbound_smtp_password": "",
            "outbound_smtp_server": "",
            "outbound_smtp_port": "587",
            "rollbar_access_token": ""
        }
    )

    return proj_dir


if __name__ == '__main__':
    sys.exit(main())



'''
Utils for functional methodologies throughout Gooey

'''


def merge_dictionaries(x,y):
    """
    Merge 2 dictionaries with y taking overwriting x if a key collision is found

    This is mainly useful for maintaining the dictionary arguments to allow for more expressive & extensible arguments.
    https://stackoverflow.com/questions/38987/how-do-i-merge-two-dictionaries-in-a-single-expression-in-python-taking-union-o

    Args:
        x (dict): Input dictionary
        y (dict): Input dictionary

    Returns:
        The combined dictionary of x & y with y taking preference on the occasion of key collision
    """
    if x is None:
        x = {}
    if y is None:
        y = {}
    try:
        return {**x,**y}
    except:
        z = x.copy()
        z.update(y)
        return z



from gooey import Gooey, GooeyParser


@Gooey(program_name="Gooey!")
def parse_args(default_name):
    # import sys
    # print(sys.argv)
    parser = GooeyParser(prog="Gooey", description="Gooey turns your CLI apps into beautiful GUIs!")
    parser.add_argument('data_directory',
                        action='store',
                        default='scale=',
                        type=lambda x: 'foo ' + x,
                        widget='DirChooser',
                        # gooey_options={
                        #     'validator': {
                        #         'test': "__import__('re').search('\d+x\d+', user_input) != None",
                        #         'message': 'oops'
                        #     }
                        # }
                        )
    args = parser.parse_args()
    print(args)

if __name__ == '__main__':
    conf = parse_args("/sample")
    print("Done")


from gooey import Gooey, GooeyParser

@Gooey(terminal_font_family='consolas')
def main():
    parser = GooeyParser()
    # parser.add_argument('-default-text-area', widget="Textarea")
    # parser.add_argument('-large-text-area', widget="Textarea", gooey_options={"height": 180, "full_width": True})
    parser.parser.parse_args()
    print("""
  /\_____\    
 _\ \__/_/_   
/\_\ \_____\  
\ \ \/ / / /  
 \ \/ /\/ /   
  \/_/\/_/    
    """)


if __name__ == "__main__":
    main()


import unittest
from random import randint
from unittest.mock import patch

from tests.harness import instrumentGooey
from gooey import GooeyParser
from gooey.tests import *

class TestNumbericInputs(unittest.TestCase):

    def makeParser(self, **kwargs):
        parser = GooeyParser(description='description')
        parser.add_argument('--input', **kwargs)
        return parser


    def testDefault(self):
        cases = [
            [{'widget': 'IntegerField'}, 0],
            [{'default': 0, 'widget': 'IntegerField'}, 0],
            [{'default': 10, 'widget': 'IntegerField'}, 10],
            [{'default': 76, 'widget': 'IntegerField'}, 76],
            # note that WX caps the value
            # unless explicitly widened via gooey_options
            [{'default': 81234, 'widget': 'IntegerField'}, 100],
            # here we set the max to something higher than
            # the default and all works as expected.
            # this is a TODO for validation
            [{'default': 81234, 'widget': 'IntegerField', 'gooey_options': {'max': 99999}}, 81234],
            # Initial Value cases
            [{'widget': 'IntegerField', 'gooey_options': {'initial_value': 0}}, 0],
            [{'widget': 'IntegerField', 'gooey_options': {'initial_value': 10}}, 10],
            [{'widget': 'IntegerField', 'gooey_options': {'initial_value': 76}}, 76],
            # note that WX caps the value
            # unless explicitly widened via gooey_options
            [{'widget': 'IntegerField', 'gooey_options': {'initial_value': 81234}}, 100],
            # here we set the max to something higher than
            # the default and all works as expected.
            # this is a TODO for validation
            [{'widget': 'IntegerField', 'gooey_options': {'initial_value': 81234, 'max': 99999}}, 81234],

            [{'widget': 'DecimalField'}, 0],
            [{'default': 0, 'widget': 'DecimalField'}, 0],
            [{'default': 81234, 'widget': 'DecimalField'}, 100],
            [{'default': 81234, 'widget': 'DecimalField', 'gooey_options': {'max': 99999}}, 81234],
            # Initial Value cases
            [{'widget': 'DecimalField', 'gooey_options': {'initial_value': 0}}, 0],
            [{'widget': 'DecimalField', 'gooey_options': {'initial_value': 10}}, 10],
            [{'widget': 'DecimalField', 'gooey_options': {'initial_value': 76}}, 76],
            # note that WX caps the value
            # unless explicitly widened via gooey_options
            [{'widget': 'DecimalField', 'gooey_options': {'initial_value': 81234}}, 100],
            # here we set the max to something higher than
            # the default and all works as expected.
            # this is a TODO for validation
            [{'widget': 'DecimalField', 'gooey_options': {'initial_value': 81234, 'max': 99999}}, 81234],
        ]
        for inputs, expected in cases:
            with self.subTest(inputs):
                parser = self.makeParser(**inputs)
                with instrumentGooey(parser) as (app, gooeyApp):
                    input = gooeyApp.configs[0].reifiedWidgets[0]
                    self.assertEqual(input.getValue()['rawValue'], expected)

    def testGooeyOptions(self):
        cases = [
            {'widget': 'DecimalField', 'gooey_options': {'min': -100, 'max': 1234, 'increment': 1.240}},
            {'widget': 'DecimalField', 'gooey_options': {'min': 1234, 'max': 3456, 'increment': 2.2}},
            {'widget': 'IntegerField', 'gooey_options': {'min': -100, 'max': 1234}},
            {'widget': 'IntegerField', 'gooey_options': {'min': 1234, 'max': 3456}}
        ];
        using = {
            'min': lambda widget: widget.GetMin(),
            'max': lambda widget: widget.GetMax(),
            'increment': lambda widget: widget.GetIncrement(),

        }
        for case in cases:
            with self.subTest(case):
                parser = self.makeParser(**case)
                with instrumentGooey(parser) as (app, gooeyApp):
                    wxWidget = gooeyApp.configs[0].reifiedWidgets[0].widget
                    for option, value in case['gooey_options'].items():
                        self.assertEqual(using[option](wxWidget), value)


    def testZerosAreReturned(self):
        """
        Originally the formatter was dropping '0' due to
        it being interpreted as falsey
        """
        parser = self.makeParser(widget='IntegerField')
        with instrumentGooey(parser) as (app, gooeyApp):
            field = gooeyApp.configs[0].reifiedWidgets[0]
            result = field.getValue()
            self.assertEqual(result['rawValue'], 0)
            self.assertIsNotNone(result['cmd'])

    def testNoLossOfPrecision(self):
        parser = self.makeParser(widget='DecimalField', default=12.23534, gooey_options={'precision': 20})
        with instrumentGooey(parser) as (app, gooeyApp):
            field = gooeyApp.configs[0].reifiedWidgets[0]
            result = field.getValue()
            self.assertEqual(result['rawValue'], 12.23534)
            self.assertIsNotNone(result['cmd'])




if __name__ == '__main__':
    unittest.main()


"""
A tool for cheating in the game Getting Over It
"""
import datetime
import itertools
import json
import os
import pickle
import sys
import time
import winreg
from bs4 import BeautifulSoup
from win32 import win32api, win32security

from gooey import Gooey, GooeyParser

priviliges_error = (
    'Looks like we can\'t access the registry where Getting Over It keeps its save data.'
    '\nMake sure you\'re running as an Administrator! Right click the SaveIt Icon and '
    'select "Run As Administrator"'
)

directory_error = (
    'Unable to create a folder for your save files!\n'
    'Make sure to run SaveOverIt! in a directory '
    'where you have full permissions'
)


@Gooey(
    program_name="Getting Over It!",
    image_dir='imgs',
    poll_external_updates=True)
def main():
    parser = GooeyParser(description='Getting Over it without the "Hurt"')
    g = parser.add_argument_group()
    stuff = g.add_mutually_exclusive_group(
        required=True,
        gooey_options={
            'initial_selection': 0
        }
    )
    stuff.add_argument(
        '--save',
        metavar='Save Progress',
        action='store_true',
        help='Take a snap shot of your current progress!'
    )
    stuff.add_argument(
        '--load',
        metavar='Load Previous Save',
        help='Load a Previous save file',
        dest='filename',
        widget='Dropdown',
        choices=list_savefiles(),
        gooey_options={
            'validator': {
                'test': 'user_input != "Select Option"',
                'message': 'Choose a save file from the list'
            }
        }
    )

    args = parser.parse_args()
    print(args)
    if args.save:
        save_registry(collect_regvals(load_regkey()))
    else:
        replace_reg_values(load_regkey(), load_registry(os.path.join('saves', args.filename)))
        print('Successfully Loaded snapshot!')
        print('Make sure to fix your mouse sensitivity! ^_^\n')



def adjust_privileges():
    priv_flags = win32security.TOKEN_ADJUST_PRIVILEGES | win32security.TOKEN_QUERY
    token = win32security.OpenProcessToken(win32api.GetCurrentProcess(), priv_flags)
    privilege_id = win32security.LookupPrivilegeValue(None, "SeBackupPrivilege")
    win32security.AdjustTokenPrivileges(token, 0, [(privilege_id, win32security.SE_PRIVILEGE_ENABLED)])

def check_privileges():
    """
    See if we're running as an administrator by attempting
    to write something to the registry
    """
    try:
        winreg.SetValueEx(load_regkey(), 'com_gooey__tst_write', None, 4,0)
    except:
        show_error_modal(priviliges_error)
        sys.exit(1)

def replace_reg_values(key, data):
    for subkey, value, _type in data:
        winreg.SetValueEx(key, subkey, 0, _type, value)


def mk_savedir():
    try:
        os.mkdir('saves')
    except IOError as e:
        if not e.winerror == 183:  # already exists
            show_error_modal(directory_error)
            sys.exit(1)


def list_savefiles():
    return list(sorted(os.listdir('saves'), reverse=True))


def show_error_modal(error_msg):
    # wx imported locally so as not to interfere with Gooey
    import wx
    app = wx.App()
    dlg = wx.MessageDialog(None, error_msg, 'Error', wx.ICON_ERROR)
    dlg.ShowModal()
    dlg.Destroy()


def load_regkey():
    return winreg.OpenKey(
        winreg.HKEY_CURRENT_USER,
        r"SOFTWARE\Bennett Foddy\Getting Over It",
        0,
        winreg.KEY_READ | winreg.KEY_SET_VALUE
    )


def start_backup_process(duration):
    save_registry(collect_regvals(load_regkey()))
    print('backed up saved at {}'.format(datetime.datetime.now().isoformat()))
    print()
    time.sleep(duration)


def load_registry(filename):
    with open(filename,'rb') as f:
        return pickle.load(f)

def parse_int(s):
    return int(float(s))


def save_registry(data):
    next_number = '{:04d}'.format(len(list_savefiles()) + 1)
    now = datetime.datetime.now().strftime('%b %d, %Y - %H.%M%p')
    xpos, ypos = map(parse_int, get_pos_info(data))
    filename = 'Snapshot {} @ {} [-x-position {} -y-position {}].save'.format(next_number, now, xpos, ypos)
    with open(os.path.join('saves', filename), 'wb') as f:
        f.write(pickle.dumps(data))
    print('Saved {}!'.format(filename))


def get_pos_info(data):
    for subkey, value, _type in data:
        if subkey.startswith('SaveGame'):
            soup = BeautifulSoup(value.decode('utf-8'), 'html.parser').find('campos')
            return [soup.x.text, soup.y.text]


def collect_regvals(regkey):
    values = []
    for index in itertools.count(0):
        try:
            values.append(winreg.EnumValue(regkey, index))
        except OSError:
            break
    return values


if __name__ == '__main__':
    mk_savedir()
    adjust_privileges()
    check_privileges()
    if 'gooey-seed-ui' in sys.argv:
        print(json.dumps({'--load': list_savefiles()}))
    else:
        main()



from gooey import Gooey, GooeyParser


@Gooey
def main():
    parser = GooeyParser()
    parser.add_argument('numbersonly',
    action='store',
    gooey_options={
        'validator':{
            'test': "re.search(r'[\d]+', user_input)",
            'message': 'must be a number!'
        }
    })
    args = parser.parse_args()


if __name__ == '__main__':
    main()


'''
Utils for retrieving resources when when in a frozen state.

MEIPASS explanation:
https://pythonhosted.org/PyInstaller/#run-time-operation
'''
import os
import sys


def is_frozen():
    return getattr(sys, 'frozen', False)


def getResourcePath(*args):
    if is_frozen():
        # MEIPASS explanation:
        # https://pythonhosted.org/PyInstaller/#run-time-operation
        basedir = getattr(sys, '_MEIPASS', None)
        if not basedir:
            basedir = os.path.dirname(sys.executable)
        resource_dir = os.path.join(basedir, 'gooey')
        if not os.path.isdir(resource_dir):
            raise IOError(
                (
                "Cannot locate Gooey resources. It seems that the program was frozen, "
                "but resource files were not copied into directory of the executable "
                "file. Please copy `languages` and `images` folders from gooey module "
                "directory into `{}{}` directory. Using PyInstaller, a.datas in .spec "
                "file must be specified.".format(resource_dir, os.sep)))
    else:
        resource_dir = os.path.normpath(
            os.path.join(os.path.dirname(__file__), '..', '..'))
    return os.path.join(resource_dir, *args)


def localResourcePath(path):
    """
    A packaging aware util for getting the path to the local working directory.
    When non-packaged, this is os.getcwd(), when packaged, it will be the local
    (dynamic) directory where PyInstaller decompresses content.
    """
    if is_frozen():
        basedir = getattr(sys, '_MEIPASS', None)
        return os.path.join(basedir or sys.executable, path)
    else:
        return os.path.join(os.getcwd(), path)



'''
Created on Dec 21, 2013
 __          __  _
 \ \        / / | |
  \ \  /\  / /__| | ___ ___  _ __ ___   ___
   \ \/  \/ / _ \ |/ __/ _ \| '_ ` _ \ / _ \
    \  /\  /  __/ | (_| (_) | | | | | |  __/
  ___\/__\/ \___|_|\___\___/|_| |_| |_|\___|
 |__   __|
    | | ___
    | |/ _ \
    | | (_) |
   _|_|\___/                    _ _
  / ____|                      | | |
 | |  __  ___   ___   ___ _   _| | |
 | | |_ |/ _ \ / _ \ / _ \ | | | | |
 | |__| | (_) | (_) |  __/ |_| |_|_|
  \_____|\___/ \___/ \___|\__, (_|_)
                           __/ |
                          |___/

@author: Chris
'''

from gooey.python_bindings.gooey_decorator import Gooey
from gooey.python_bindings.gooey_parser import GooeyParser


@Gooey(
    program_name='Gooey Demo',
    sidebar_title="Your Custom Title",
    show_sidebar=False,
    dump_build_config=True,
    # body_bg_color='#ffffff'
    menu=[{
        'name': 'File',
        'items': [{
                'type': 'AboutDialog',
                'menuTitle': 'About',
                'name': 'Gooey Layout Demo',
                'description': 'An example of Gooey\'s layout flexibility',
                'version': '1.2.1',
                'copyright': '2018',
                'website': 'https://github.com/chriskiehl/Gooey',
                'developer': 'http://chriskiehl.com/',
                'license': 'MIT'
            }, {
                'type': 'MessageDialog',
                'menuTitle': 'Information',
                'caption': 'My Message',
                'message': 'I am demoing an informational dialog!'
            }, {
                'type': 'Link',
                'menuTitle': 'Visit Our Site',
                'url': 'https://github.com/chriskiehl/Gooey'
            }]
        },{
        'name': 'Help',
        'items': [{
            'type': 'Link',
            'menuTitle': 'Documentation',
            'url': 'https://www.readthedocs.com/foo'
        }]
    }]
)
def main():
    message = (
        'Hi there!\n\n' 
        'Welcome to Gooey! \nThis is a demo of the flexible layouts and overall' 
        'customization you can achieve by using argument groups and '
        'the new gooey_options feature.')



    import sys
    print(sys.argv)
    desc = "Gooey transforms your CLI applications into beautiful GUIs!"
    file_help_msg = "Name of the file you want to process"
    my_cool_parser = GooeyParser(description=desc, add_help=False)

    # categories = my_cool_parser.add_argument_group(
    #     'Input Stage',
    #     gooey_options={
    #         'show_border': True,
    #         # 'label_color': '#FF9900',
    #         'columns': 2,
    #         # 'margin_top': 30
    #     }
    # )
    #
    # categories.add_argument(
    #     '--subcategory',
    #     metavar='File',
    #     help='Path the audio file to encode.',
    #     widget='FileChooser',
    #     required=True,
    #     gooey_options={
    #     })
    #
    # categories.add_argument(
    #     '--subcategory21',
    #     metavar='File',
    #     help='Path the audio file to encode.',
    #     widget='FileChooser',
    #     required=True,
    #     gooey_options={
    #     })


    # categories.add_argument(
    #     '--parent-category',
    #     metavar='Bitrate',
    #     help='The constant or variable bitrate (depending on codec choice)',
    #     choices=['a', 'b', 'c'],
    #     required=True,
    #     gooey_options={
    #         'label_color': '#FF9900',
    #         'label_bg_color': '#0000FF',
    #         # 'help_color': '#ff00ff',
    #         'help_bg_color': '#ff00ff'
    #     })



    search_options = my_cool_parser.add_argument_group(
        'Output Stage',
        'Specify the desired output behavior for the encoded file.',
        gooey_options={
            'show_border': True,
            'columns': 2,
            'margin_top': 25
        }
    )

    search_options.add_argument('--query',
                                metavar="Output File",
                                help='The output destination for the encoded file',
                                widget='FileChooser',
                                gooey_options={'full_width': True})
    #
    search_flags = search_options.add_argument_group('Resampling',
                                                     gooey_options={'show_border': True}
                                                     )
    search_flags.add_argument('--buy-it-now',
                              metavar='Lowpass',
                              help="Frequency(kHz), lowpass filter cutoff above freq.",
                              action='store_true',
                              widget='BlockCheckbox',
                              gooey_options={
                                  'checkbox_label': 'Enable'
                              })
    search_flags.add_argument('--auction',
                              metavar='Resample',
                              help="Sampling frequency of output file(kHz)",
                              action='store_true',
                              widget='BlockCheckbox',
                              gooey_options={
                                  'checkbox_label': 'Enable'
                              })

    # price_range = search_options.add_argument_group('Price_Range',
    #                                                 gooey_options={'show_border': True}
    #                                                 )
    #
    # price_range.add_argument('--price-min',
    #                          help='This'
    #                          )
    # price_range.add_argument(
    #     '--price-max',
    #     metavar='Priority',
    #     help='sets the process priority (Windows and OS/2-specific)',
    #     choices=[0,1,2,3,4],
    #     default=2
    # )

    my_cool_parser.print_help()
    args = my_cool_parser.parse_args()
    print(args)
    print("Hiya!")
    for i in range(20):
        import time
        print('Howdy', i)
        time.sleep(.3)
    # print(args.listboxie)


def here_is_smore():
    pass


if __name__ == '__main__':
    main()



from gooey import Gooey, GooeyParser


@Gooey(dump_build_config=True, program_name="Widget Demo")
def main():
    desc = "Example application to show Gooey's various widgets"
    file_help_msg = "Name of the file you want to process"
    my_cool_parser = GooeyParser(description=desc)
    verbosity = my_cool_parser.add_mutually_exclusive_group(required=False)
    verbosity.add_argument('-t', '--verbozze', dest='verbose',
                           action="store_true", help="Show more details")
    verbosity.add_argument('-q', '--quiet', dest='quiet',
                           action="store_true", help="Only output on error")

    my_cool_parser.parse_args()
    print("Hey")

def here_is_more():
    pass
if __name__ == '__main__':
    main()